;=============================================================================
; Original MOD file: "beast.MOD"
; Original MOD name: "Beast-Playtune2     "
; ASM file created by Mod2PSG V1.5 by Martin Konrad (mkon@gmx.de)
;=============================================================================



;=============================================================================
; Constants
;=============================================================================
RAM_START    = $C000
CONTROL_PORT = $DC

;=============================================================================
; PSGMOD variables
;=============================================================================
PSGMOD_PATTERN_ADDRESS  = RAM_START     ;(word)
PSGMOD_SONG_START       = RAM_START + 2 ;(word)
PSGMOD_SONG_POSITION    = RAM_START + 4 ;(byte)
PSGMOD_PATTERN_POSITION = RAM_START + 5 ;(byte)
PSGMOD_CURRENT_SPEED    = RAM_START + 6 ;(byte)
PSGMOD_SPEED_COUNTER    = RAM_START + 7 ;(byte)
PSGMOD_SOUND_DISABLED   = RAM_START + 8 ;(byte)

;=============================================================================
; Misc variables
;=============================================================================
VBLANK_COUNTER          = RAM_START + 9  ;(byte)
PREVIOUS_CONTROL_STATUS = RAM_START + 10 ;(byte)



;=============================================================================
; Start code
;=============================================================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START

;=============================================================================
; IRQ handler
;=============================================================================
.org $0038
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_COUNTER
  inc (HL)

  exx
  ex af, af'
  ei
  reti

;=============================================================================
; NMI handler
;=============================================================================
.org $0066
  retn



START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

;=============================================================================
; Song start
;=============================================================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1                       ; wait one VBlank
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE   ; play next note

  in a, (CONTROL_PORT)            ; get control status
  ld b, a                         ; save it to b
  ld a, (PREVIOUS_CONTROL_STATUS) ; button already pressed before?
  bit 4, a
  jr Z, BUTTON_NOT_PRESSED_AGAIN  ; jump away if yes
  ld a, b                         ; button now pressed?
  bit 4, a
  jr NZ, BUTTON_NOT_PRESSED_AGAIN ; jump away if not
  call PSGMOD_TOGGLE_SOUND        ; toggle sound
BUTTON_NOT_PRESSED_AGAIN:
  ld a, b                         ; get control status from b
  ld (PREVIOUS_CONTROL_STATUS), a ; save control status to previous
                                  ; control status

  jr SONG_LOOP
;=============================================================================
; Program end
;=============================================================================

.include PSGMOD.INC



VWAIT:
  ld a, 0
  ld (VBLANK_COUNTER), a
VWAIT_LOOP:
  ld a, (VBLANK_COUNTER)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

PSGMOD_SONG:
.db 0,1,0,1,2,3,4,5
.db 6,7,6,8,9,10,11,12
.db 13,14,13,15,16,17,18,19
.db 20,21,20,22,23,24,25,26
.db 128,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0

; Pattern 0:
.dw 2962,2961,4470,770,15,2961,15,847,
.dw 15,2961,15,847,15,2961,15,847,
.dw 2802,2961,2813,847,15,2961,15,847,
.dw 15,2961,2813,847,15,2961,15,847,
.dw 2962,2961,4470,770,15,2961,15,847,
.dw 15,2961,15,847,15,2961,15,847,
.dw 2802,2961,2813,847,15,2961,15,847,
.dw 2962,2961,2813,847,15,2961,15,847,
.dw 15,2961,4470,770,15,2961,15,847,
.dw 2802,2961,15,847,15,2961,15,847,
.dw 15,2961,2813,847,15,2961,15,847,
.dw 2962,2961,2813,847,15,2961,15,847,
.dw 2962,2961,4470,770,15,2961,15,847,
.dw 15,2961,15,847,15,2961,15,847,
.dw 2802,2961,2813,847,15,2961,15,847,
.dw 15,2961,2813,847,15,2961,15,847,
.dw 2962,2961,4470,770,15,2961,15,847,
.dw 15,2961,15,847,15,2961,15,847,
.dw 2802,2961,2813,847,15,2961,15,847,
.dw 15,2961,2813,847,15,2961,15,847,
.dw 2962,2961,4470,770,15,2961,15,847,
.dw 15,2961,15,847,15,2961,15,847,
.dw 2802,2961,2813,847,15,2961,15,847,
.dw 2962,2961,2813,847,15,2961,15,847,
.dw 15,2961,4470,770,15,2961,15,847,
.dw 2802,2961,15,847,15,2961,15,847,
.dw 15,2961,2813,847,15,2961,15,847,
.dw 2962,2961,2813,770,15,2961,15,847,
.dw 2962,2961,4470,770,15,2961,15,847,
.dw 15,2961,15,770,15,2962,15,847,
.dw 2802,1489,2813,770,15,1489,15,847,
.dw 15,1489,2813,770,15,1489,15,847,
; Pattern 1:
.dw 2642,3969,4470,770,15,3969,15,911,
.dw 15,3969,15,911,15,3969,15,911,
.dw 3970,3969,2813,911,15,3969,15,911,
.dw 15,3969,2813,911,15,3969,15,783,
.dw 2642,3969,4470,770,15,3969,15,911,
.dw 15,3969,15,911,15,3969,15,911,
.dw 3970,3969,2813,911,15,3969,15,911,
.dw 2642,3969,2813,911,15,3969,15,911,
.dw 15,3969,4470,770,15,3969,15,911,
.dw 3970,3969,15,911,15,3969,15,911,
.dw 15,3969,2813,911,15,3969,15,911,
.dw 2498,3969,2813,911,15,3969,15,911,
.dw 2498,3969,4470,770,15,3969,15,911,
.dw 2498,3969,15,911,15,3969,15,911,
.dw 2642,3969,2813,911,15,3969,15,911,
.dw 15,3969,2813,911,15,3969,15,911,
.dw 2642,3969,4470,770,15,3969,15,911,
.dw 15,3969,15,911,15,3969,15,911,
.dw 3970,3969,2813,911,15,3969,15,911,
.dw 15,3969,2813,911,15,3969,15,911,
.dw 2642,3969,4470,770,15,3969,15,911,
.dw 15,3969,15,911,15,3969,15,911,
.dw 3970,3969,2813,911,15,3969,15,911,
.dw 2642,3969,2813,911,15,3969,15,911,
.dw 15,3969,4470,770,15,3969,15,911,
.dw 3970,3969,15,911,15,3969,15,911,
.dw 15,3969,2813,911,15,3969,15,911,
.dw 2498,3969,2813,770,15,3969,15,911,
.dw 2498,3969,1984,770,15,3969,15,911,
.dw 2498,3969,15,770,15,3970,15,911,
.dw 2642,1985,1984,770,15,1985,15,911,
.dw 15,1985,1984,770,15,1985,15,911,
; Pattern 2:
.dw 2962,2961,4470,770,15,2961,15,975,
.dw 15,2961,15,975,15,2961,15,975,
.dw 1490,2961,2813,975,15,2961,15,975,
.dw 15,2961,2813,975,15,2961,15,783,
.dw 2962,2961,4470,770,15,2961,15,975,
.dw 1986,2961,15,975,15,2961,15,975,
.dw 15,2961,2813,975,15,2961,15,975,
.dw 2962,2961,2813,975,15,2961,15,975,
.dw 1874,2961,4470,770,15,2961,15,975,
.dw 15,2961,15,975,15,2961,15,975,
.dw 2962,2961,2813,975,15,2961,15,975,
.dw 1986,2961,2813,975,15,2961,15,975,
.dw 15,2961,4470,770,15,2961,15,975,
.dw 1666,2961,15,975,15,2961,15,975,
.dw 1874,2961,2813,975,15,2961,15,975,
.dw 1986,2961,2813,975,15,2961,15,975,
.dw 2962,2961,4470,770,15,2961,15,975,
.dw 15,2961,15,975,15,2961,15,975,
.dw 1490,2961,2813,975,15,2961,15,975,
.dw 15,2961,2813,975,15,2961,15,975,
.dw 2962,2961,4470,770,15,2961,15,975,
.dw 1986,2961,15,975,15,2961,15,975,
.dw 15,2961,2813,975,15,2961,15,975,
.dw 2962,2961,2813,975,15,2961,15,975,
.dw 1874,2961,4470,770,15,2961,15,975,
.dw 15,2961,15,975,15,2961,15,975,
.dw 2962,2961,2813,975,15,2961,15,975,
.dw 1986,2961,2813,770,15,2961,15,975,
.dw 15,2961,4470,770,15,2961,15,975,
.dw 2498,2961,15,770,15,2962,15,975,
.dw 2642,1489,2813,770,15,1489,15,975,
.dw 2962,1489,2813,770,15,1489,15,975,
; Pattern 3:
.dw 3330,3969,4470,770,15,3969,15,783,
.dw 15,3969,15,783,15,3969,15,783,
.dw 1986,3969,2813,783,15,3969,15,783,
.dw 15,3969,2813,783,15,3969,15,783,
.dw 3330,3969,4470,770,15,3969,15,783,
.dw 2642,3969,15,783,15,3969,15,783,
.dw 15,3969,2813,783,15,3969,15,783,
.dw 3330,3969,2813,783,15,3969,15,783,
.dw 2498,3969,4470,770,15,3969,15,783,
.dw 15,3969,15,783,15,3969,15,783,
.dw 3330,3969,2813,783,15,3969,15,783,
.dw 2642,3969,2813,783,15,3969,15,783,
.dw 15,3969,4470,770,15,3969,15,783,
.dw 2226,3969,15,783,15,3969,15,783,
.dw 2498,3969,2813,783,15,3969,15,783,
.dw 2642,3969,2813,783,15,3969,15,783,
.dw 3330,3969,4470,770,15,3969,15,783,
.dw 15,3969,15,783,15,3969,15,783,
.dw 1986,3969,2813,783,15,3969,15,783,
.dw 15,3969,2813,783,15,3969,15,783,
.dw 3330,3969,4470,770,15,3969,15,783,
.dw 2642,3969,15,783,15,3969,15,783,
.dw 15,3969,2813,783,15,3969,15,783,
.dw 3330,3969,2813,783,15,3969,15,783,
.dw 2498,3969,4470,770,15,3969,15,783,
.dw 15,3969,15,783,15,3969,15,783,
.dw 3330,3969,2813,783,15,3969,15,783,
.dw 2642,3969,2813,770,15,3969,15,783,
.dw 15,3969,1984,770,15,3969,15,783,
.dw 1666,3969,15,770,15,3970,15,783,
.dw 1762,1985,1984,770,15,1985,15,783,
.dw 1986,1985,1984,770,15,1985,15,783,
; Pattern 4:
.dw 2961,2961,4470,770,2961,2961,15,847,
.dw 2968,2961,15,847,2969,2961,15,847,
.dw 1489,2961,2813,847,1489,2961,15,847,
.dw 1496,2961,2813,847,1497,2961,15,783,
.dw 2961,2961,4470,770,2962,2961,15,847,
.dw 1985,2961,15,847,1985,2961,15,847,
.dw 1992,2961,2813,847,1993,2961,15,847,
.dw 2961,2961,2813,847,2962,2961,15,847,
.dw 1873,2961,4470,770,1873,2961,15,847,
.dw 1880,2961,15,847,1881,2961,15,847,
.dw 2961,2961,2813,847,2962,2961,15,847,
.dw 1985,2961,2813,847,1985,2961,15,847,
.dw 1992,2961,4470,770,1993,2961,15,847,
.dw 1665,2961,15,847,1666,2961,15,847,
.dw 1873,2961,2813,847,1874,2961,15,847,
.dw 1985,2961,2813,847,1986,2961,15,847,
.dw 2961,2961,4470,770,2961,2961,15,847,
.dw 2968,2961,15,847,2969,2961,15,847,
.dw 1489,2961,2813,847,1489,2961,15,847,
.dw 1496,2961,2813,847,1497,2961,15,847,
.dw 2961,2961,4470,770,2962,2961,15,847,
.dw 1985,2961,15,847,1985,2961,15,847,
.dw 1992,2961,2813,847,1993,2961,15,847,
.dw 2961,2961,2813,847,2962,2961,15,847,
.dw 1873,2961,4470,770,1873,2961,15,847,
.dw 1880,2961,15,847,1881,2961,15,847,
.dw 2961,2961,2813,847,2962,2961,15,847,
.dw 1985,2961,2813,770,1985,2961,15,847,
.dw 1992,2961,4470,770,1993,2961,15,847,
.dw 2497,2961,15,770,2498,2962,15,847,
.dw 2641,1489,2813,770,2642,1489,15,847,
.dw 2961,1489,2813,770,2961,1489,15,847,
; Pattern 5:
.dw 3329,3969,4470,770,3329,3969,15,911,
.dw 3336,3969,15,911,3337,3969,15,911,
.dw 1985,3969,2813,911,1985,3969,15,911,
.dw 1992,3969,2813,911,1993,3969,15,783,
.dw 3329,3969,4470,770,3330,3969,15,911,
.dw 2641,3969,15,911,2641,3969,15,911,
.dw 2648,3969,2813,911,2649,3969,15,911,
.dw 3329,3969,2813,911,3330,3969,15,911,
.dw 2497,3969,4470,770,2497,3969,15,911,
.dw 2504,3969,15,911,2505,3969,15,911,
.dw 3329,3969,2813,911,3330,3969,15,911,
.dw 2641,3969,2813,911,2641,3969,15,911,
.dw 2648,3969,4470,770,2649,3969,15,911,
.dw 2225,3969,15,911,2226,3969,15,911,
.dw 2497,3969,2813,911,2498,3969,15,911,
.dw 2641,3969,2813,911,2642,3969,15,911,
.dw 3329,3969,4470,770,3329,3969,15,911,
.dw 3336,3969,15,911,3337,3969,15,911,
.dw 1985,3969,2813,911,1985,3969,15,911,
.dw 1992,3969,2813,911,1993,3969,15,911,
.dw 3329,3969,4470,770,3330,3969,15,911,
.dw 2641,3969,15,911,2641,3969,15,911,
.dw 2648,3969,2813,911,2649,3969,15,911,
.dw 3329,3969,2813,911,3330,3969,15,911,
.dw 2497,3969,4470,770,2497,3969,15,911,
.dw 2504,3969,15,911,2505,3969,15,911,
.dw 3329,3969,2813,911,3330,3969,15,911,
.dw 2641,3969,2813,770,2641,3969,15,911,
.dw 2648,3969,1984,770,2649,3969,15,911,
.dw 1665,3969,15,770,1666,3970,15,911,
.dw 1873,1985,1984,770,1874,1985,15,911,
.dw 1985,1985,1984,770,1985,1985,15,911,
; Pattern 6:
.dw 2802,2801,4470,770,15,2801,15,975,
.dw 15,2801,15,975,15,2801,15,975,
.dw 2642,2801,2813,975,15,2801,15,975,
.dw 15,2801,2813,975,15,2801,15,783,
.dw 2802,2801,4470,770,15,2801,15,975,
.dw 15,2801,15,975,15,2801,15,975,
.dw 2642,2801,2813,975,15,2801,15,975,
.dw 2802,2801,2813,975,15,2801,15,975,
.dw 15,2801,4470,770,15,2801,15,975,
.dw 2642,2801,15,975,15,2801,15,975,
.dw 15,2801,2813,975,15,2801,15,975,
.dw 2802,2801,2813,975,15,2801,15,975,
.dw 2802,2801,4470,770,15,2801,15,975,
.dw 15,2801,15,975,15,2801,15,975,
.dw 2642,2801,2813,975,15,2801,15,975,
.dw 15,2801,2813,975,15,2801,15,975,
.dw 2802,2801,4470,770,15,2801,15,975,
.dw 15,2801,15,975,15,2801,15,975,
.dw 2642,2801,2813,975,15,2801,15,975,
.dw 15,2801,2813,975,15,2801,15,975,
.dw 2802,2801,4470,770,15,2801,15,975,
.dw 15,2801,15,975,15,2801,15,975,
.dw 2642,2801,2813,975,15,2801,15,975,
.dw 2802,2801,2813,975,15,2801,15,975,
.dw 15,2801,4470,770,15,2801,15,975,
.dw 2642,2801,15,975,15,2801,15,975,
.dw 15,2801,2813,975,15,2801,15,975,
.dw 2802,2801,2813,770,15,2801,15,975,
.dw 2802,2801,4470,770,15,2801,15,975,
.dw 15,2801,15,770,15,2802,15,975,
.dw 2642,1393,2813,770,15,1393,15,975,
.dw 15,1393,2813,770,15,1393,15,975,
; Pattern 7:
.dw 2498,3745,4470,770,15,3745,15,783,
.dw 15,3745,15,783,15,3745,15,783,
.dw 3746,3745,2813,783,15,3745,15,783,
.dw 15,3745,2813,783,15,3745,15,783,
.dw 2498,3745,4470,770,15,3745,15,783,
.dw 15,3745,15,783,15,3745,15,783,
.dw 3746,3745,2813,783,15,3745,15,783,
.dw 2498,3745,2813,783,15,3745,15,783,
.dw 15,3745,4470,770,15,3745,15,783,
.dw 3746,3745,15,783,15,3745,15,783,
.dw 15,3745,2813,783,15,3745,15,783,
.dw 2354,3745,2813,783,15,3745,15,783,
.dw 2354,3745,4470,770,15,3745,15,783,
.dw 2354,3745,15,783,15,3745,15,783,
.dw 2498,3745,2813,783,15,3745,15,783,
.dw 15,3745,2813,783,15,3745,15,783,
.dw 2498,3745,4470,770,15,3745,15,783,
.dw 15,3745,15,783,15,3745,15,783,
.dw 3746,3745,2813,783,15,3745,15,783,
.dw 15,3745,2813,783,15,3745,15,783,
.dw 2498,3745,4470,770,15,3745,15,783,
.dw 15,3745,15,783,15,3745,15,783,
.dw 3746,3745,2813,783,15,3745,15,783,
.dw 2498,3745,2813,783,15,3745,15,783,
.dw 15,3745,4470,770,15,3745,15,783,
.dw 3746,3745,15,783,15,3745,15,783,
.dw 15,3745,2813,783,15,3745,15,783,
.dw 2498,3745,2813,770,15,3745,15,783,
.dw 2498,3745,1984,770,15,3745,15,783,
.dw 15,3745,15,770,15,3746,15,783,
.dw 3746,1873,1984,770,15,1873,15,783,
.dw 15,1873,1984,770,15,1873,15,783,
; Pattern 8:
.dw 2498,3745,4470,770,15,3745,15,847,
.dw 15,3745,15,847,15,3745,15,847,
.dw 2354,3745,2813,847,15,3745,15,847,
.dw 15,3745,2813,847,15,3745,15,783,
.dw 2498,3745,4470,770,15,3745,15,847,
.dw 15,3745,15,847,15,3745,15,847,
.dw 2354,3745,2813,847,15,3745,15,847,
.dw 2498,3745,2813,847,15,3745,15,847,
.dw 15,3745,4470,770,15,3745,15,847,
.dw 2354,3745,15,847,15,3745,15,847,
.dw 15,3745,2813,847,15,3745,15,847,
.dw 2498,3745,2813,847,15,3745,15,847,
.dw 2498,3745,4470,770,15,3745,15,847,
.dw 15,3745,15,847,15,3745,15,847,
.dw 2354,3745,2813,847,15,3745,15,847,
.dw 15,3745,2813,847,15,3745,15,847,
.dw 2498,3745,4470,770,15,3745,15,847,
.dw 15,3745,15,847,15,3745,15,847,
.dw 2354,3745,2813,847,15,3745,15,847,
.dw 15,3745,2813,847,15,3745,15,847,
.dw 2498,3745,4470,770,15,3745,15,847,
.dw 15,3745,15,847,15,3745,15,847,
.dw 2354,3745,2813,847,15,3745,15,847,
.dw 2498,3745,2813,847,15,3745,15,847,
.dw 15,3745,4470,770,15,3745,15,847,
.dw 2354,3745,15,847,15,3745,15,847,
.dw 15,3745,2813,847,15,3745,15,847,
.dw 2354,3745,2813,770,15,3745,15,847,
.dw 2354,3745,1984,770,15,3745,15,847,
.dw 2354,3745,15,770,15,3746,15,847,
.dw 2498,1873,1984,770,15,1873,15,847,
.dw 15,1873,1984,770,15,1873,15,847,
; Pattern 9:
.dw 2802,2801,4470,770,15,2801,15,911,
.dw 15,2801,15,911,15,2801,15,911,
.dw 1394,2801,2813,911,15,2801,15,911,
.dw 15,2801,2813,911,15,2801,15,783,
.dw 2802,2801,4470,770,15,2801,15,911,
.dw 1874,2801,15,911,15,2801,15,911,
.dw 15,2801,2813,911,15,2801,15,911,
.dw 2802,2801,2813,911,15,2801,15,911,
.dw 1762,2801,4470,770,15,2801,15,911,
.dw 15,2801,15,911,15,2801,15,911,
.dw 2802,2801,2813,911,15,2801,15,911,
.dw 1874,2801,2813,911,15,2801,15,911,
.dw 15,2801,4470,770,15,2801,15,911,
.dw 1570,2801,15,911,15,2801,15,911,
.dw 1762,2801,2813,911,15,2801,15,911,
.dw 1874,2801,2813,911,15,2801,15,911,
.dw 2802,2801,4470,770,15,2801,15,911,
.dw 15,2801,15,911,15,2801,15,911,
.dw 1394,2801,2813,911,15,2801,15,911,
.dw 15,2801,2813,911,15,2801,15,911,
.dw 2802,2801,4470,770,15,2801,15,911,
.dw 1874,2801,15,911,15,2801,15,911,
.dw 15,2801,2813,911,15,2801,15,911,
.dw 2802,2801,2813,911,15,2801,15,911,
.dw 1762,2801,4470,770,15,2801,15,911,
.dw 15,2801,15,911,15,2801,15,911,
.dw 2802,2801,2813,911,15,2801,15,911,
.dw 1874,2801,2813,770,15,2801,15,911,
.dw 15,2801,4470,770,15,2801,15,911,
.dw 2354,2801,15,770,15,2802,15,911,
.dw 2498,1393,2813,770,15,1393,15,911,
.dw 2802,1393,2813,770,15,1393,15,911,
; Pattern 10:
.dw 3138,3745,4470,770,15,3745,15,975,
.dw 15,3745,15,975,15,3745,15,975,
.dw 1874,3745,2813,975,15,3745,15,975,
.dw 15,3745,2813,975,15,3745,15,783,
.dw 3138,3745,4470,770,15,3745,15,975,
.dw 2498,3745,15,975,15,3745,15,975,
.dw 15,3745,2813,975,15,3745,15,975,
.dw 3138,3745,2813,975,15,3745,15,975,
.dw 2354,3745,4470,770,15,3745,15,975,
.dw 15,3745,15,975,15,3745,15,975,
.dw 3138,3745,2813,975,15,3745,15,975,
.dw 2498,3745,2813,975,15,3745,15,975,
.dw 15,3745,4470,770,15,3745,15,975,
.dw 2098,3745,15,975,15,3745,15,975,
.dw 2354,3745,2813,975,15,3745,15,975,
.dw 2498,3745,2813,975,15,3745,15,975,
.dw 3138,3745,4470,770,15,3745,15,975,
.dw 15,3745,15,975,15,3745,15,975,
.dw 1874,3745,2813,975,15,3745,15,975,
.dw 15,3745,2813,975,15,3745,15,975,
.dw 3138,3745,4470,770,15,3745,15,975,
.dw 2498,3745,15,975,15,3745,15,975,
.dw 15,3745,2813,975,15,3745,15,975,
.dw 3138,3745,2813,975,15,3745,15,975,
.dw 2354,3745,4470,770,15,3745,15,975,
.dw 15,3745,15,975,15,3745,15,975,
.dw 3138,3745,2813,975,15,3745,15,975,
.dw 2498,3745,2813,770,15,3745,15,975,
.dw 15,3745,1984,770,15,3745,15,975,
.dw 1570,3745,15,770,15,3746,15,975,
.dw 1666,1873,1984,770,15,1873,15,975,
.dw 1874,1873,1984,770,15,1873,15,975,
; Pattern 11:
.dw 2801,2801,4470,770,2801,2801,15,783,
.dw 2808,2801,15,783,2809,2801,15,783,
.dw 1393,2801,2813,783,1393,2801,15,783,
.dw 1400,2801,2813,783,1401,2801,15,783,
.dw 2801,2801,4470,770,2802,2801,15,783,
.dw 1873,2801,15,783,1873,2801,15,783,
.dw 1880,2801,2813,783,1881,2801,15,783,
.dw 2801,2801,2813,783,2802,2801,15,783,
.dw 1761,2801,4470,770,1761,2801,15,783,
.dw 1768,2801,15,783,1769,2801,15,783,
.dw 2801,2801,2813,783,2802,2801,15,783,
.dw 1873,2801,2813,783,1873,2801,15,783,
.dw 1880,2801,4470,770,1881,2801,15,783,
.dw 1569,2801,15,783,1570,2801,15,783,
.dw 1761,2801,2813,783,1762,2801,15,783,
.dw 1873,2801,2813,783,1874,2801,15,783,
.dw 2801,2801,4470,770,2801,2801,15,783,
.dw 2808,2801,15,783,2809,2801,15,783,
.dw 1393,2801,2813,783,1393,2801,15,783,
.dw 1400,2801,2813,783,1401,2801,15,783,
.dw 2801,2801,4470,770,2802,2801,15,783,
.dw 1873,2801,15,783,1873,2801,15,783,
.dw 1880,2801,2813,783,1881,2801,15,783,
.dw 2801,2801,2813,783,2802,2801,15,783,
.dw 1761,2801,4470,770,1761,2801,15,783,
.dw 1768,2801,15,783,1769,2801,15,783,
.dw 2801,2801,2813,783,2802,2801,15,783,
.dw 1873,2801,2813,770,1873,2801,15,783,
.dw 1880,2801,4470,770,1881,2801,15,783,
.dw 2353,2801,15,770,2354,2802,15,783,
.dw 2497,1393,2813,770,2498,1393,15,783,
.dw 2801,1393,2813,770,2801,1393,15,783,
; Pattern 12:
.dw 3137,3745,4470,770,3137,3745,15,847,
.dw 3144,3745,15,847,3145,3745,15,847,
.dw 1873,3745,2813,847,1873,3745,15,847,
.dw 1880,3745,2813,847,1881,3745,15,783,
.dw 3137,3745,4470,770,3138,3745,15,847,
.dw 2497,3745,15,847,2497,3745,15,847,
.dw 2504,3745,2813,847,2505,3745,15,847,
.dw 3137,3745,2813,847,3138,3745,15,847,
.dw 2353,3745,4470,770,2353,3745,15,847,
.dw 2360,3745,15,847,2361,3745,15,847,
.dw 3137,3745,2813,847,3138,3745,15,847,
.dw 2497,3745,2813,847,2497,3745,15,847,
.dw 2504,3745,4470,770,2505,3745,15,847,
.dw 2097,3745,15,847,2098,3745,15,847,
.dw 2353,3745,2813,847,2354,3745,15,847,
.dw 2497,3745,2813,847,2498,3745,15,847,
.dw 3137,3745,4470,770,3137,3745,15,847,
.dw 3144,3745,15,847,3145,3745,15,847,
.dw 1873,3745,2813,847,1873,3745,15,847,
.dw 1880,3745,2813,847,1881,3745,15,847,
.dw 3137,3745,4470,770,3138,3745,15,847,
.dw 2497,3745,15,847,2497,3745,15,847,
.dw 2504,3745,2813,847,2505,3745,15,847,
.dw 3137,3745,2813,847,3138,3745,15,847,
.dw 2353,3745,4470,770,2353,3745,15,847,
.dw 2360,3745,15,847,2361,3745,15,847,
.dw 3137,3745,2813,847,3138,3745,15,847,
.dw 2497,3745,2813,770,2497,3745,15,847,
.dw 2504,3745,1984,770,2505,3745,15,847,
.dw 1569,3745,15,770,1570,3746,15,847,
.dw 1665,1873,1984,770,1666,1873,15,847,
.dw 1873,1873,1984,770,1873,1873,15,847,
; Pattern 13:
.dw 2642,2641,4470,770,15,2641,15,911,
.dw 15,2641,15,911,15,2641,15,911,
.dw 2498,2641,2813,911,15,2641,15,911,
.dw 15,2641,2813,911,15,2641,15,783,
.dw 2642,2641,4470,770,15,2641,15,911,
.dw 15,2641,15,911,15,2641,15,911,
.dw 2498,2641,2813,911,15,2641,15,911,
.dw 2642,2641,2813,911,15,2641,15,911,
.dw 15,2641,4470,770,15,2641,15,911,
.dw 2498,2641,15,911,15,2641,15,911,
.dw 15,2641,2813,911,15,2641,15,911,
.dw 2642,2641,2813,911,15,2641,15,911,
.dw 2642,2641,4470,770,15,2641,15,911,
.dw 15,2641,15,911,15,2641,15,911,
.dw 2498,2641,2813,911,15,2641,15,911,
.dw 15,2641,2813,911,15,2641,15,911,
.dw 2642,2641,4470,770,15,2641,15,911,
.dw 15,2641,15,911,15,2641,15,911,
.dw 2498,2641,2813,911,15,2641,15,911,
.dw 15,2641,2813,911,15,2641,15,911,
.dw 2642,2641,4470,770,15,2641,15,911,
.dw 15,2641,15,911,15,2641,15,911,
.dw 2498,2641,2813,911,15,2641,15,911,
.dw 2642,2641,2813,911,15,2641,15,911,
.dw 15,2641,4470,770,15,2641,15,911,
.dw 2498,2641,15,911,15,2641,15,911,
.dw 15,2641,2813,911,15,2641,15,911,
.dw 2642,2641,2813,770,15,2641,15,911,
.dw 2642,2641,4470,770,15,2641,15,911,
.dw 15,2641,15,770,15,2642,15,911,
.dw 2498,1313,2813,770,15,1313,15,911,
.dw 15,1313,2813,770,15,1313,15,911,
; Pattern 14:
.dw 2354,3537,4470,770,15,3537,15,975,
.dw 15,3537,15,975,15,3537,15,975,
.dw 3538,3537,2813,975,15,3537,15,975,
.dw 15,3537,2813,975,15,3537,15,783,
.dw 2354,3537,4470,770,15,3537,15,975,
.dw 15,3537,15,975,15,3537,15,975,
.dw 3538,3537,2813,975,15,3537,15,975,
.dw 2354,3537,2813,975,15,3537,15,975,
.dw 15,3537,4470,770,15,3537,15,975,
.dw 3538,3537,15,975,15,3537,15,975,
.dw 15,3537,2813,975,15,3537,15,975,
.dw 2226,3537,2813,975,15,3537,15,975,
.dw 2226,3537,4470,770,15,3537,15,975,
.dw 2226,3537,15,975,15,3537,15,975,
.dw 2354,3537,2813,975,15,3537,15,975,
.dw 15,3537,2813,975,15,3537,15,975,
.dw 2354,3537,4470,770,15,3537,15,975,
.dw 15,3537,15,975,15,3537,15,975,
.dw 3538,3537,2813,975,15,3537,15,975,
.dw 15,3537,2813,975,15,3537,15,975,
.dw 2354,3537,4470,770,15,3537,15,975,
.dw 15,3537,15,975,15,3537,15,975,
.dw 3538,3537,2813,975,15,3537,15,975,
.dw 2354,3537,2813,975,15,3537,15,975,
.dw 15,3537,4470,770,15,3537,15,975,
.dw 3538,3537,15,975,15,3537,15,975,
.dw 15,3537,2813,975,15,3537,15,975,
.dw 2354,3537,2813,770,15,3537,15,975,
.dw 2354,3537,1984,770,15,3537,15,975,
.dw 15,3537,15,770,15,3538,15,975,
.dw 3538,1761,1984,770,15,1761,15,975,
.dw 15,1761,1984,770,15,1761,15,975,
; Pattern 15:
.dw 2354,3537,4470,770,15,3537,15,783,
.dw 15,3537,15,783,15,3537,15,783,
.dw 2226,3537,2813,783,15,3537,15,783,
.dw 15,3537,2813,783,15,3537,15,783,
.dw 2354,3537,4470,770,15,3537,15,783,
.dw 15,3537,15,783,15,3537,15,783,
.dw 2226,3537,2813,783,15,3537,15,783,
.dw 2354,3537,2813,783,15,3537,15,783,
.dw 15,3537,4470,770,15,3537,15,783,
.dw 2226,3537,15,783,15,3537,15,783,
.dw 15,3537,2813,783,15,3537,15,783,
.dw 2354,3537,2813,783,15,3537,15,783,
.dw 2354,3537,4470,770,15,3537,15,783,
.dw 15,3537,15,783,15,3537,15,783,
.dw 2226,3537,2813,783,15,3537,15,783,
.dw 15,3537,2813,783,15,3537,15,783,
.dw 2354,3537,4470,770,15,3537,15,783,
.dw 15,3537,15,783,15,3537,15,783,
.dw 2226,3537,2813,783,15,3537,15,783,
.dw 15,3537,2813,783,15,3537,15,783,
.dw 2354,3537,4470,770,15,3537,15,783,
.dw 15,3537,15,783,15,3537,15,783,
.dw 2226,3537,2813,783,15,3537,15,783,
.dw 2354,3537,2813,783,15,3537,15,783,
.dw 15,3537,4470,770,15,3537,15,783,
.dw 2226,3537,15,783,15,3537,15,783,
.dw 15,3537,2813,783,15,3537,15,783,
.dw 2226,3537,2813,770,15,3537,15,783,
.dw 2226,3537,1984,770,15,3537,15,783,
.dw 2226,3537,15,770,15,3538,15,783,
.dw 2354,1761,1984,770,15,1761,15,783,
.dw 15,1761,1984,770,15,1761,15,783,
; Pattern 16:
.dw 2642,2641,4470,770,15,2641,15,847,
.dw 15,2641,15,847,15,2641,15,847,
.dw 1314,2641,2813,847,15,2641,15,847,
.dw 15,2641,2813,847,15,2641,15,783,
.dw 2642,2641,4470,770,15,2641,15,847,
.dw 1762,2641,15,847,15,2641,15,847,
.dw 15,2641,2813,847,15,2641,15,847,
.dw 2642,2641,2813,847,15,2641,15,847,
.dw 1666,2641,4470,770,15,2641,15,847,
.dw 15,2641,15,847,15,2641,15,847,
.dw 2642,2641,2813,847,15,2641,15,847,
.dw 1762,2641,2813,847,15,2641,15,847,
.dw 15,2641,4470,770,15,2641,15,847,
.dw 1490,2641,15,847,15,2641,15,847,
.dw 1666,2641,2813,847,15,2641,15,847,
.dw 1762,2641,2813,847,15,2641,15,847,
.dw 2642,2641,4470,770,15,2641,15,847,
.dw 15,2641,15,847,15,2641,15,847,
.dw 1314,2641,2813,847,15,2641,15,847,
.dw 15,2641,2813,847,15,2641,15,847,
.dw 2642,2641,4470,770,15,2641,15,847,
.dw 1762,2641,15,847,15,2641,15,847,
.dw 15,2641,2813,847,15,2641,15,847,
.dw 2642,2641,2813,847,15,2641,15,847,
.dw 1666,2641,4470,770,15,2641,15,847,
.dw 15,2641,15,847,15,2641,15,847,
.dw 2642,2641,2813,847,15,2641,15,847,
.dw 1762,2641,2813,770,15,2641,15,847,
.dw 15,2641,4470,770,15,2641,15,847,
.dw 2226,2641,15,770,15,2642,15,847,
.dw 2354,1313,2813,770,15,1313,15,847,
.dw 2642,1313,2813,770,15,1313,15,847,
; Pattern 17:
.dw 2962,3537,4470,770,15,3537,15,911,
.dw 15,3537,15,911,15,3537,15,911,
.dw 1762,3537,2813,911,15,3537,15,911,
.dw 15,3537,2813,911,15,3537,15,783,
.dw 2962,3537,4470,770,15,3537,15,911,
.dw 2354,3537,15,911,15,3537,15,911,
.dw 15,3537,2813,911,15,3537,15,911,
.dw 2962,3537,2813,911,15,3537,15,911,
.dw 2226,3537,4470,770,15,3537,15,911,
.dw 15,3537,15,911,15,3537,15,911,
.dw 2962,3537,2813,911,15,3537,15,911,
.dw 2354,3537,2813,911,15,3537,15,911,
.dw 15,3537,4470,770,15,3537,15,911,
.dw 1986,3537,15,911,15,3537,15,911,
.dw 2226,3537,2813,911,15,3537,15,911,
.dw 2354,3537,2813,911,15,3537,15,911,
.dw 2962,3537,4470,770,15,3537,15,911,
.dw 15,3537,15,911,15,3537,15,911,
.dw 1762,3537,2813,911,15,3537,15,911,
.dw 15,3537,2813,911,15,3537,15,911,
.dw 2962,3537,4470,770,15,3537,15,911,
.dw 2354,3537,15,911,15,3537,15,911,
.dw 15,3537,2813,911,15,3537,15,911,
.dw 2962,3537,2813,911,15,3537,15,911,
.dw 2226,3537,4470,770,15,3537,15,911,
.dw 15,3537,15,911,15,3537,15,911,
.dw 2962,3537,2813,911,15,3537,15,911,
.dw 2354,3537,2813,770,15,3537,15,911,
.dw 15,3537,1984,770,15,3537,15,911,
.dw 1490,3537,15,770,15,3538,15,911,
.dw 1570,1761,1984,770,15,1761,15,911,
.dw 1762,1761,1984,770,15,1761,15,911,
; Pattern 18:
.dw 2641,2641,4470,770,2641,2641,15,975,
.dw 2648,2641,15,975,2649,2641,15,975,
.dw 1313,2641,2813,975,1313,2641,15,975,
.dw 1320,2641,2813,975,1321,2641,15,783,
.dw 2641,2641,4470,770,2642,2641,15,975,
.dw 1761,2641,15,975,1761,2641,15,975,
.dw 1768,2641,2813,975,1769,2641,15,975,
.dw 2641,2641,2813,975,2642,2641,15,975,
.dw 1665,2641,4470,770,1665,2641,15,975,
.dw 1672,2641,15,975,1673,2641,15,975,
.dw 2641,2641,2813,975,2642,2641,15,975,
.dw 1761,2641,2813,975,1761,2641,15,975,
.dw 1768,2641,4470,770,1769,2641,15,975,
.dw 1489,2641,15,975,1490,2641,15,975,
.dw 1665,2641,2813,975,1666,2641,15,975,
.dw 1761,2641,2813,975,1762,2641,15,975,
.dw 2641,2641,4470,770,2641,2641,15,975,
.dw 2648,2641,15,975,2649,2641,15,975,
.dw 1313,2641,2813,975,1313,2641,15,975,
.dw 1320,2641,2813,975,1321,2641,15,975,
.dw 2641,2641,4470,770,2642,2641,15,975,
.dw 1761,2641,15,975,1761,2641,15,975,
.dw 1768,2641,2813,975,1769,2641,15,975,
.dw 2641,2641,2813,975,2642,2641,15,975,
.dw 1665,2641,4470,770,1665,2641,15,975,
.dw 1672,2641,15,975,1673,2641,15,975,
.dw 2641,2641,2813,975,2642,2641,15,975,
.dw 1761,2641,2813,770,1761,2641,15,975,
.dw 1768,2641,4470,770,1769,2641,15,975,
.dw 2225,2641,15,770,2226,2642,15,975,
.dw 2353,1313,2813,770,2354,1313,15,975,
.dw 2641,1313,2813,770,2641,1313,15,975,
; Pattern 19:
.dw 2961,3537,4470,770,2961,3537,15,783,
.dw 2968,3537,15,783,2969,3537,15,783,
.dw 1761,3537,2813,783,1761,3537,15,783,
.dw 1768,3537,2813,783,1769,3537,15,783,
.dw 2961,3537,4470,770,2962,3537,15,783,
.dw 2353,3537,15,783,2353,3537,15,783,
.dw 2360,3537,2813,783,2361,3537,15,783,
.dw 2961,3537,2813,783,2962,3537,15,783,
.dw 2225,3537,4470,770,2225,3537,15,783,
.dw 2232,3537,15,783,2233,3537,15,783,
.dw 2961,3537,2813,783,2962,3537,15,783,
.dw 2353,3537,2813,783,2353,3537,15,783,
.dw 2360,3537,4470,770,2361,3537,15,783,
.dw 1985,3537,15,783,1986,3537,15,783,
.dw 2225,3537,2813,783,2226,3537,15,783,
.dw 2353,3537,2813,783,2354,3537,15,783,
.dw 2961,3537,4470,770,2961,3537,15,783,
.dw 2968,3537,15,783,2969,3537,15,783,
.dw 1761,3537,2813,783,1761,3537,15,783,
.dw 1768,3537,2813,783,1769,3537,15,783,
.dw 2961,3537,4470,770,2962,3537,15,783,
.dw 2353,3537,15,783,2353,3537,15,783,
.dw 2360,3537,2813,783,2361,3537,15,783,
.dw 2961,3537,2813,783,2962,3537,15,783,
.dw 2225,3537,4470,770,2225,3537,15,783,
.dw 2232,3537,15,783,2233,3537,15,783,
.dw 2961,3537,2813,783,2962,3537,15,783,
.dw 2353,3537,2813,770,2353,3537,15,783,
.dw 2360,3537,1984,770,2361,3537,15,783,
.dw 1489,3537,15,770,1490,3538,15,783,
.dw 1569,1761,1984,770,1570,1761,15,783,
.dw 1761,1761,1984,770,1761,1761,15,783,
; Pattern 20:
.dw 2498,2497,4470,770,15,2497,15,847,
.dw 15,2497,15,847,15,2497,15,847,
.dw 2354,2497,2813,847,15,2497,15,847,
.dw 15,2497,2813,847,15,2497,15,783,
.dw 2498,2497,4470,770,15,2497,15,847,
.dw 15,2497,15,847,15,2497,15,847,
.dw 2354,2497,2813,847,15,2497,15,847,
.dw 2498,2497,2813,847,15,2497,15,847,
.dw 15,2497,4470,770,15,2497,15,847,
.dw 2354,2497,15,847,15,2497,15,847,
.dw 15,2497,2813,847,15,2497,15,847,
.dw 2498,2497,2813,847,15,2497,15,847,
.dw 2498,2497,4470,770,15,2497,15,847,
.dw 15,2497,15,847,15,2497,15,847,
.dw 2354,2497,2813,847,15,2497,15,847,
.dw 15,2497,2813,847,15,2497,15,847,
.dw 2498,2497,4470,770,15,2497,15,847,
.dw 15,2497,15,847,15,2497,15,847,
.dw 2354,2497,2813,847,15,2497,15,847,
.dw 15,2497,2813,847,15,2497,15,847,
.dw 2498,2497,4470,770,15,2497,15,847,
.dw 15,2497,15,847,15,2497,15,847,
.dw 2354,2497,2813,847,15,2497,15,847,
.dw 2498,2497,2813,847,15,2497,15,847,
.dw 15,2497,4470,770,15,2497,15,847,
.dw 2354,2497,15,847,15,2497,15,847,
.dw 15,2497,2813,847,15,2497,15,847,
.dw 2498,2497,2813,770,15,2497,15,847,
.dw 2498,2497,4470,770,15,2497,15,847,
.dw 15,2497,15,770,15,2498,15,847,
.dw 2354,1249,2813,770,15,1249,15,847,
.dw 15,1249,2813,770,15,1249,15,847,
; Pattern 21:
.dw 2226,3329,4470,770,15,3329,15,911,
.dw 15,3329,15,911,15,3329,15,911,
.dw 3330,3329,2813,911,15,3329,15,911,
.dw 15,3329,2813,911,15,3329,15,783,
.dw 2226,3329,4470,770,15,3329,15,911,
.dw 15,3329,15,911,15,3329,15,911,
.dw 3330,3329,2813,911,15,3329,15,911,
.dw 2226,3329,2813,911,15,3329,15,911,
.dw 15,3329,4470,770,15,3329,15,911,
.dw 3330,3329,15,911,15,3329,15,911,
.dw 15,3329,2813,911,15,3329,15,911,
.dw 2098,3329,2813,911,15,3329,15,911,
.dw 2098,3329,4470,770,15,3329,15,911,
.dw 2098,3329,15,911,15,3329,15,911,
.dw 2226,3329,2813,911,15,3329,15,911,
.dw 15,3329,2813,911,15,3329,15,911,
.dw 2226,3329,4470,770,15,3329,15,911,
.dw 15,3329,15,911,15,3329,15,911,
.dw 3330,3329,2813,911,15,3329,15,911,
.dw 15,3329,2813,911,15,3329,15,911,
.dw 2226,3329,4470,770,15,3329,15,911,
.dw 15,3329,15,911,15,3329,15,911,
.dw 3330,3329,2813,911,15,3329,15,911,
.dw 2226,3329,2813,911,15,3329,15,911,
.dw 15,3329,4470,770,15,3329,15,911,
.dw 3330,3329,15,911,15,3329,15,911,
.dw 15,3329,2813,911,15,3329,15,911,
.dw 2098,3329,2813,770,15,3329,15,911,
.dw 2098,3329,1984,770,15,3329,15,911,
.dw 2098,3329,15,770,15,3330,15,911,
.dw 2226,1665,1984,770,15,1665,15,911,
.dw 15,1665,1984,770,15,1665,15,911,
; Pattern 22:
.dw 2226,3329,4470,770,15,3329,15,975,
.dw 15,3329,15,975,15,3329,15,975,
.dw 2098,3329,2813,975,15,3329,15,975,
.dw 15,3329,2813,975,15,3329,15,783,
.dw 2226,3329,4470,770,15,3329,15,975,
.dw 15,3329,15,975,15,3329,15,975,
.dw 2098,3329,2813,975,15,3329,15,975,
.dw 2226,3329,2813,975,15,3329,15,975,
.dw 15,3329,4470,770,15,3329,15,975,
.dw 2098,3329,15,975,15,3329,15,975,
.dw 15,3329,2813,975,15,3329,15,975,
.dw 2226,3329,2813,975,15,3329,15,975,
.dw 2226,3329,4470,770,15,3329,15,975,
.dw 15,3329,15,975,15,3329,15,975,
.dw 2098,3329,2813,975,15,3329,15,975,
.dw 15,3329,2813,975,15,3329,15,975,
.dw 2226,3329,4470,770,15,3329,15,975,
.dw 15,3329,15,975,15,3329,15,975,
.dw 2098,3329,2813,975,15,3329,15,975,
.dw 15,3329,2813,975,15,3329,15,975,
.dw 2226,3329,4470,770,15,3329,15,975,
.dw 15,3329,15,975,15,3329,15,975,
.dw 2098,3329,2813,975,15,3329,15,975,
.dw 2226,3329,2813,975,15,3329,15,975,
.dw 15,3329,4470,770,15,3329,15,975,
.dw 2098,3329,15,975,15,3329,15,975,
.dw 15,3329,2813,975,15,3329,15,975,
.dw 2226,3329,2813,770,15,3329,15,975,
.dw 2226,3329,1984,770,15,3329,15,975,
.dw 2226,3329,15,770,15,3330,15,975,
.dw 2098,1665,1984,770,15,1665,15,975,
.dw 15,1665,1984,770,15,1665,15,975,
; Pattern 23:
.dw 2498,2497,4470,770,15,2497,15,783,
.dw 15,2497,15,783,15,2497,15,783,
.dw 1249,2497,2813,783,15,2497,15,783,
.dw 15,2497,2813,783,15,2497,15,783,
.dw 2498,2497,4470,770,15,2497,15,783,
.dw 1666,2497,15,783,15,2497,15,783,
.dw 15,2497,2813,783,15,2497,15,783,
.dw 2498,2497,2813,783,15,2497,15,783,
.dw 1570,2497,4470,770,15,2497,15,783,
.dw 15,2497,15,783,15,2497,15,783,
.dw 2498,2497,2813,783,15,2497,15,783,
.dw 1666,2497,2813,783,15,2497,15,783,
.dw 15,2497,4470,770,15,2497,15,783,
.dw 1394,2497,15,783,15,2497,15,783,
.dw 1570,2497,2813,783,15,2497,15,783,
.dw 1666,2497,2813,783,15,2497,15,783,
.dw 2498,2497,4470,770,15,2497,15,783,
.dw 15,2497,15,783,15,2497,15,783,
.dw 1249,2497,2813,783,15,2497,15,783,
.dw 15,2497,2813,783,15,2497,15,783,
.dw 2498,2497,4470,770,15,2497,15,783,
.dw 1666,2497,15,783,15,2497,15,783,
.dw 15,2497,2813,783,15,2497,15,783,
.dw 2498,2497,2813,783,15,2497,15,783,
.dw 1570,2497,4470,770,15,2497,15,783,
.dw 15,2497,15,783,15,2497,15,783,
.dw 2498,2497,2813,783,15,2497,15,783,
.dw 1666,2497,2813,770,15,2497,15,783,
.dw 15,2497,4470,770,15,2497,15,783,
.dw 2098,2497,15,770,15,2498,15,783,
.dw 2226,1249,2813,770,15,1249,15,783,
.dw 2498,1249,2813,770,15,1249,15,783,
; Pattern 24:
.dw 2802,3329,4470,770,15,3329,15,847,
.dw 15,3329,15,847,15,3329,15,847,
.dw 1666,3329,2813,847,15,3329,15,847,
.dw 15,3329,2813,847,15,3329,15,783,
.dw 2802,3329,4470,770,15,3329,15,847,
.dw 2226,3329,15,847,15,3329,15,847,
.dw 15,3329,2813,847,15,3329,15,847,
.dw 2802,3329,2813,847,15,3329,15,847,
.dw 2098,3329,4470,770,15,3329,15,847,
.dw 15,3329,15,847,15,3329,15,847,
.dw 2802,3329,2813,847,15,3329,15,847,
.dw 2226,3329,2813,847,15,3329,15,847,
.dw 15,3329,4470,770,15,3329,15,847,
.dw 1874,3329,15,847,15,3329,15,847,
.dw 2098,3329,2813,847,15,3329,15,847,
.dw 2226,3329,2813,847,15,3329,15,847,
.dw 2802,3329,4470,770,15,3329,15,847,
.dw 15,3329,15,847,15,3329,15,847,
.dw 1666,3329,2813,847,15,3329,15,847,
.dw 15,3329,2813,847,15,3329,15,847,
.dw 2802,3329,4470,770,15,3329,15,847,
.dw 2226,3329,15,847,15,3329,15,847,
.dw 15,3329,2813,847,15,3329,15,847,
.dw 2802,3329,2813,847,15,3329,15,847,
.dw 2098,3329,4470,770,15,3329,15,847,
.dw 15,3329,15,847,15,3329,15,847,
.dw 2802,3329,2813,847,15,3329,15,847,
.dw 2226,3329,2813,770,15,3329,15,847,
.dw 15,3329,1984,770,15,3329,15,847,
.dw 1874,3329,15,770,15,3330,15,847,
.dw 2098,1665,1984,770,15,1665,15,847,
.dw 2226,1665,1984,770,15,1665,15,847,
; Pattern 25:
.dw 2497,2497,4470,770,2497,2497,15,911,
.dw 2504,2497,15,911,2505,2497,15,911,
.dw 1249,2497,2813,911,1249,2497,15,911,
.dw 1256,2497,2813,911,1257,2497,15,783,
.dw 2497,2497,4470,770,2498,2497,15,911,
.dw 1665,2497,15,911,1665,2497,15,911,
.dw 1672,2497,2813,911,1673,2497,15,911,
.dw 2497,2497,2813,911,2498,2497,15,911,
.dw 1569,2497,4470,770,1569,2497,15,911,
.dw 1576,2497,15,911,1577,2497,15,911,
.dw 2497,2497,2813,911,2498,2497,15,911,
.dw 1665,2497,2813,911,1665,2497,15,911,
.dw 1672,2497,4470,770,1673,2497,15,911,
.dw 1393,2497,15,911,1394,2497,15,911,
.dw 1569,2497,2813,911,1570,2497,15,911,
.dw 1665,2497,2813,911,1666,2497,15,911,
.dw 2497,2497,4470,770,2497,2497,15,911,
.dw 2504,2497,15,911,2505,2497,15,911,
.dw 1249,2497,2813,911,1249,2497,15,911,
.dw 1256,2497,2813,911,1257,2497,15,911,
.dw 2497,2497,4470,770,2498,2497,15,911,
.dw 1665,2497,15,911,1665,2497,15,911,
.dw 1672,2497,2813,911,1673,2497,15,911,
.dw 2497,2497,2813,911,2498,2497,15,911,
.dw 1569,2497,4470,770,1569,2497,15,911,
.dw 1576,2497,15,911,1577,2497,15,911,
.dw 2497,2497,2813,911,2498,2497,15,911,
.dw 1665,2497,2813,770,1665,2497,15,911,
.dw 1672,2497,4470,770,1673,2497,15,911,
.dw 2097,2497,15,770,2098,2498,15,911,
.dw 2225,1249,2813,770,2226,1249,15,911,
.dw 2497,1249,2813,770,2497,1249,15,911,
; Pattern 26:
.dw 2801,3329,4470,770,2801,3329,15,975,
.dw 2808,3329,15,975,2809,3329,15,975,
.dw 1665,3329,2813,975,1665,3329,15,975,
.dw 1672,3329,2813,975,1673,3329,15,783,
.dw 2801,3329,4470,770,2802,3329,15,975,
.dw 2225,3329,15,975,2225,3329,15,975,
.dw 2232,3329,2813,975,2233,3329,15,975,
.dw 2801,3329,2813,975,2802,3329,15,975,
.dw 2097,3329,4470,770,2097,3329,15,975,
.dw 2104,3329,15,975,2105,3329,15,975,
.dw 2801,3329,2813,975,2802,3329,15,975,
.dw 2225,3329,2813,975,2225,3329,15,975,
.dw 2232,3329,4470,770,2233,3329,15,975,
.dw 1873,3329,15,975,1874,3329,15,975,
.dw 2097,3329,2813,975,2098,3329,15,975,
.dw 2225,3329,2813,975,2226,3329,15,975,
.dw 2801,3329,4470,770,2801,3329,15,975,
.dw 2808,3329,15,975,2809,3329,15,975,
.dw 1665,3329,2813,975,1665,3329,15,975,
.dw 1672,3329,2813,975,1673,3329,15,975,
.dw 2801,3329,4470,770,2802,3329,15,975,
.dw 2225,3329,15,975,2225,3329,15,975,
.dw 2232,3329,2813,975,2233,3329,15,975,
.dw 2801,3329,2813,975,2802,3329,15,975,
.dw 2097,3329,4470,770,2097,3329,15,975,
.dw 2104,3329,15,975,2105,3329,15,975,
.dw 2801,3329,2813,975,2802,3329,15,975,
.dw 2225,3329,2813,770,2225,3329,15,975,
.dw 2232,3329,1984,770,2233,3329,15,975,
.dw 1873,3329,15,770,1874,3330,15,975,
.dw 2097,1665,1984,770,2098,1665,15,975,
.dw 2225,1665,1984,770,2225,1665,15,975,

.org $10000
.end
