;=============================================================================
; Original MOD file: "monkey.MOD"
; Original MOD name: "monkey island       "
; ASM file created by Mod2PSG V1.5 by Martin Konrad (mkon@gmx.de)
;=============================================================================



;=============================================================================
; Constants
;=============================================================================
RAM_START    = $C000
CONTROL_PORT = $DC

;=============================================================================
; PSGMOD variables
;=============================================================================
PSGMOD_PATTERN_ADDRESS  = RAM_START     ;(word)
PSGMOD_SONG_START       = RAM_START + 2 ;(word)
PSGMOD_SONG_POSITION    = RAM_START + 4 ;(byte)
PSGMOD_PATTERN_POSITION = RAM_START + 5 ;(byte)
PSGMOD_CURRENT_SPEED    = RAM_START + 6 ;(byte)
PSGMOD_SPEED_COUNTER    = RAM_START + 7 ;(byte)
PSGMOD_SOUND_DISABLED   = RAM_START + 8 ;(byte)

;=============================================================================
; Misc variables
;=============================================================================
VBLANK_COUNTER          = RAM_START + 9  ;(byte)
PREVIOUS_CONTROL_STATUS = RAM_START + 10 ;(byte)



;=============================================================================
; Start code
;=============================================================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START

;=============================================================================
; IRQ handler
;=============================================================================
.org $0038
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_COUNTER
  inc (HL)

  exx
  ex af, af'
  ei
  reti

;=============================================================================
; NMI handler
;=============================================================================
.org $0066
  retn



START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

;=============================================================================
; Song start
;=============================================================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1                       ; wait one VBlank
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE   ; play next note

  in a, (CONTROL_PORT)            ; get control status
  ld b, a                         ; save it to b
  ld a, (PREVIOUS_CONTROL_STATUS) ; button already pressed before?
  bit 4, a
  jr Z, BUTTON_NOT_PRESSED_AGAIN  ; jump away if yes
  ld a, b                         ; button now pressed?
  bit 4, a
  jr NZ, BUTTON_NOT_PRESSED_AGAIN ; jump away if not
  call PSGMOD_TOGGLE_SOUND        ; toggle sound
BUTTON_NOT_PRESSED_AGAIN:
  ld a, b                         ; get control status from b
  ld (PREVIOUS_CONTROL_STATUS), a ; save control status to previous
                                  ; control status

  jr SONG_LOOP
;=============================================================================
; Program end
;=============================================================================

.include PSGMOD.INC



VWAIT:
  ld a, 0
  ld (VBLANK_COUNTER), a
VWAIT_LOOP:
  ld a, (VBLANK_COUNTER)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

PSGMOD_SONG:
.db 0,1,2,3,4,5,6,7
.db 8,9,10,11,12,13,14,5
.db 15,16,17,18,19,20,21,22
.db 23,18,19,20,21,22,23,24
.db 25,26,27,28,29,26,27,28
.db 29,30,128,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0

; Pattern 0:
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,15,1871,3976,7494,15,1871,
.dw 3976,7494,1873,1615,3976,7494,2497,1615,
.dw 3976,7494,3137,1615,3976,7494,3328,1871,
.dw 3976,7494,3328,1871,3976,7494,3328,1871,
.dw 3976,7494,3328,2383,3976,7494,3329,2383,
.dw 3976,7494,4208,1615,3976,7494,4208,1615,
.dw 3976,7494,4208,1871,3976,7494,4209,1871,
.dw 3976,7494,3744,1615,3976,7494,3744,1615,
.dw 3976,7494,3744,1359,3976,7494,3745,1359,
.dw 3976,7494,3328,1615,3976,7494,3328,1615,
.dw 3976,7494,3328,1615,3976,7494,3329,1615,
.dw 3976,7494,4208,1615,3976,7494,4208,1615,
.dw 3976,7494,4208,1359,3976,7494,4209,1359,
.dw 3976,7494,3744,1615,3976,7494,3744,1615,
.dw 3976,7494,3744,1871,3976,7494,3745,1871,
.dw 3976,7494,4992,5455,3976,7494,4992,5455,
.dw 3976,7494,4993,5455,3976,7494,3139,5455,
; Pattern 1:
.dw 15,6294,2803,2959,15,6294,2804,2959,
.dw 15,6294,2496,2633,15,6294,2496,2703,
.dw 15,6294,2496,2638,15,6294,2496,1609,
.dw 15,6294,2496,1679,15,6294,2496,2566,
.dw 15,6294,2511,2703,15,6294,2511,3142,
.dw 15,6294,2511,3215,15,6294,2511,2633,
.dw 15,6294,2511,2703,15,6294,2511,2634,
.dw 15,6294,2511,1606,15,6295,2511,1679,
.dw 15,5606,8419,2630,15,5606,8419,2703,
.dw 15,5606,8419,2633,15,5606,8419,2703,
.dw 15,5606,8420,2637,15,5606,8931,2703,
.dw 15,5606,8931,2703,15,5606,8931,2703,
.dw 15,5606,8931,2703,15,5606,8931,2703,
.dw 15,5606,8931,2703,15,5606,8931,2703,
.dw 15,5606,8931,2703,15,5606,8931,2703,
.dw 15,5606,8931,2703,15,5607,8931,2703,
.dw 15,6294,8931,2633,15,6294,8932,2703,
.dw 15,6294,8419,2703,15,6294,8419,2703,
.dw 15,6294,8419,2703,15,6294,8419,2703,
.dw 15,6294,8419,2703,15,6294,8419,2703,
.dw 15,6294,8420,2703,15,6294,7491,2703,
.dw 15,6294,7491,2703,15,6294,7491,2703,
.dw 15,6294,7491,2703,15,6295,7492,2703,
.dw 15,6678,6675,2633,15,6678,6676,2703,
.dw 15,6678,6291,2703,15,6678,6291,2703,
.dw 15,6678,6291,2703,15,6678,6292,2703,
.dw 15,6678,5603,2703,15,6679,5603,2703,
.dw 15,8419,5603,2633,15,8419,5604,2703,
.dw 15,8419,4995,2703,15,8419,4995,2703,
.dw 15,8419,4995,2703,15,8419,4996,2703,
.dw 15,8419,4211,2703,15,8419,4211,2703,
.dw 15,8419,4211,2703,15,8419,4211,2703,
; Pattern 2:
.dw 4720,1873,15,1154,15,1874,15,1231,
.dw 1886,3745,15,1167,15,3746,15,1231,
.dw 1872,3137,15,1090,15,3138,15,1167,
.dw 1872,3745,15,1154,15,3746,15,1039,
.dw 15,2497,15,1231,15,2498,15,1167,
.dw 1881,3137,15,1231,15,3138,15,1167,
.dw 1872,3745,15,1231,15,3746,15,1167,
.dw 1872,6289,15,1167,15,6290,15,1231,
.dw 15,8417,15,1167,15,8418,15,1231,
.dw 1881,4209,15,1167,15,4210,15,1231,
.dw 2096,3329,15,1092,15,3330,15,1231,
.dw 2096,5601,15,1156,15,5602,15,1231,
.dw 4720,7489,15,1156,15,7490,15,1231,
.dw 2106,3745,15,1231,1887,3746,15,1231,
.dw 1872,3137,15,1156,15,3138,15,1231,
.dw 1872,3745,15,1156,15,3746,15,1231,
.dw 15,2497,15,1167,15,2498,15,1231,
.dw 1881,3137,15,1231,15,3138,15,1231,
.dw 1872,3745,15,1231,15,3746,15,1231,
.dw 1872,6289,15,1231,15,6290,15,1231,
.dw 15,8417,15,1156,15,8418,15,1231,
.dw 1881,4209,15,1231,15,4210,15,1231,
.dw 2096,3329,15,1156,15,3330,15,1231,
.dw 2096,4209,15,1092,15,4209,15,-31537,
.dw 15,4209,15,1231,15,4209,15,1231,
.dw 15,4209,15,1231,15,4209,15,1231,
.dw 15,4209,15,1231,15,4209,15,1231,
.dw 15,4209,15,1167,15,4209,15,1231,
.dw 15,4209,15,1231,15,4209,15,1231,
.dw 15,4209,15,1231,15,4209,15,1231,
.dw 15,4209,15,1231,15,4209,15,1231,
.dw 15,4209,15,1231,15,4209,15,1231,
; Pattern 3:
.dw 15,7489,15,1154,15,7490,15,1039,
.dw 2105,3745,15,1154,15,3746,15,1039,
.dw 1872,3137,15,1167,15,3138,15,1231,
.dw 1872,3745,15,1231,15,3746,15,1039,
.dw 15,4993,3744,1039,15,4994,3744,1231,
.dw 1881,3137,3747,1039,15,3138,3748,1231,
.dw 1872,3745,3744,1039,15,3746,3745,1231,
.dw 1872,6289,3136,1231,15,6290,3137,1039,
.dw 15,8417,3328,1231,15,8418,3332,1039,
.dw 1881,4209,3744,1231,15,4210,3745,1039,
.dw 2096,3329,4208,1092,15,3330,4208,1039,
.dw 2096,5601,4211,1156,15,5602,4212,1039,
.dw 15,9457,3744,1154,15,9458,3744,1039,
.dw 2105,3745,3744,1039,15,3746,3744,1039,
.dw 2352,3137,3744,1154,15,3138,3744,1039,
.dw 2352,2353,3744,1154,15,2353,3744,1039,
.dw 2496,2353,3744,1154,2510,2353,3747,1039,
.dw 2510,2353,3753,1039,2511,2354,3754,1039,
.dw 3136,6289,4208,1218,3150,6290,4208,1039,
.dw 3150,6289,4211,1218,3151,6289,4212,1039,
.dw 3136,6289,4208,1231,3150,6289,4209,1039,
.dw 3150,6289,4720,1039,3151,6290,4724,1039,
.dw 3136,6289,4992,1231,3151,6290,4993,1039,
.dw 2496,6289,4208,1167,2511,6289,4209,1039,
.dw 2800,6289,4720,1039,2814,6289,4720,1039,
.dw 2814,6289,4723,1039,2815,6290,4724,1039,
.dw 2800,5601,4720,1220,2814,5602,4720,1039,
.dw 2814,5601,4723,1156,2815,5601,4724,1039,
.dw 3136,5601,4992,1220,3150,5601,4992,1039,
.dw 3151,5601,4992,1039,3151,5602,4992,1039,
.dw 3151,6289,4992,1220,3151,6290,4992,1039,
.dw 3151,6289,4992,1220,3151,6289,4992,1039,
; Pattern 4:
.dw 15,7489,15,1154,15,7490,15,1103,
.dw 1881,3745,15,1231,15,3746,15,1103,
.dw 1872,3137,3744,1231,15,3138,3744,1039,
.dw 1872,3745,3747,1039,15,3746,3748,1039,
.dw 15,4993,3744,1103,15,4994,3744,1039,
.dw 1881,3137,3744,1103,15,3138,3745,1039,
.dw 1872,3745,3744,1103,15,3746,3745,1039,
.dw 1872,6289,3136,1039,15,6290,3137,1103,
.dw 15,8417,3328,1218,15,8418,3332,1103,
.dw 1881,4209,3744,1039,15,4210,3745,1103,
.dw 2096,3329,4208,1090,15,3330,4208,1103,
.dw 2096,5601,4211,1154,15,5602,4212,1103,
.dw 15,9457,3744,1154,15,9458,3744,1103,
.dw 2105,3745,3744,1103,15,3746,3744,1103,
.dw 2352,3137,3744,1154,15,3138,3744,1103,
.dw 2352,2353,3744,1154,15,2353,3744,1103,
.dw 2496,2353,3744,1231,2510,2353,3744,1103,
.dw 2510,2353,3744,1103,2511,2354,3747,1103,
.dw 3136,6289,3753,1039,3150,6290,3754,1103,
.dw 3150,6289,3328,1039,3151,6289,3329,1103,
.dw 3136,6289,3136,1218,3150,6289,3136,1103,
.dw 3150,6289,3139,1026,3150,6290,3140,1103,
.dw 3150,4993,3136,1039,3151,4994,3136,1103,
.dw 2496,4993,3136,1154,2511,4993,3137,1103,
.dw 2800,4993,2800,1026,2814,4993,2800,1103,
.dw 2814,4993,2800,1103,2815,4994,2800,1103,
.dw 2800,5601,2800,1218,2814,5602,2800,1103,
.dw 2814,5601,2800,1154,2815,5601,2801,1103,
.dw 4208,5601,3328,1218,4222,5602,3328,1103,
.dw 4223,2097,3328,1026,4223,2804,3328,1103,
.dw 2096,2097,3328,1039,15,2804,3329,1103,
.dw 2096,2097,3136,1039,15,2803,3136,1103,
; Pattern 5:
.dw 15,15,3328,1231,15,15,3332,1167,
.dw 15,15,3744,1039,15,15,3748,1167,
.dw 2096,2096,4208,1039,15,2096,4209,1103,
.dw 2096,2111,3328,1103,15,2111,3328,-31729,
.dw 15,2111,3328,1167,15,2111,3328,1103,
.dw 15,2111,3328,1167,15,2111,3328,1103,
.dw 15,2111,3328,1167,15,2111,3328,1103,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1039,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1167,15,2111,3328,1167,
.dw 15,2111,3328,1231,15,2111,3328,1167,
.dw 15,2111,3328,1231,15,2111,3328,1167,
.dw 15,2111,3328,1167,15,2111,3328,1167,
.dw 15,2111,3328,1231,15,2111,3328,1167,
.dw 15,2111,3328,1231,15,2111,3329,1167,
.dw 2096,2111,4208,1039,15,2111,4209,1167,
.dw 2096,2111,3328,1167,15,2111,3328,-31601,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1039,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1231,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1167,15,2111,3328,1167,
.dw 15,2111,3328,1039,15,2111,3328,1167,
.dw 15,2111,3328,1231,15,2111,3328,1167,
.dw 15,2111,3328,1039,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
.dw 15,2111,3328,1103,15,2111,3328,1167,
; Pattern 6:
.dw 15,2500,3136,1218,15,2507,3136,1231,
.dw 15,2500,3139,1026,15,2507,3140,1231,
.dw 1568,2500,3136,1103,15,2507,3136,1167,
.dw 1568,2506,3136,1090,15,15,3137,1039,
.dw 15,1988,3328,1154,15,1995,3328,1167,
.dw 1577,1987,3328,1231,15,1988,3329,1167,
.dw 2496,2500,3328,1154,15,2507,3328,1167,
.dw 2496,1988,3331,1090,15,1995,3332,1231,
.dw 15,1876,3744,1026,15,1883,3744,1231,
.dw 2505,1876,3744,1090,15,1883,3744,1231,
.dw 1872,1876,3744,1231,15,1883,3745,1231,
.dw 1872,1875,3136,1039,15,1876,3137,1231,
.dw 15,2100,3328,1039,15,2107,3332,1231,
.dw 1881,2100,3744,1231,15,2107,3745,1231,
.dw 2096,2100,4208,1039,15,2106,4209,1231,
.dw 2096,15,3328,1039,15,15,3329,1231,
.dw 15,15,3136,1026,15,15,3136,1231,
.dw 2105,15,3139,1154,15,15,3140,1231,
.dw 1568,2499,3136,1167,15,2500,3136,1231,
.dw 1568,2499,3136,1090,15,2500,3137,1231,
.dw 15,2500,3328,1026,15,2507,3328,1231,
.dw 1577,2500,3328,1167,15,2507,3329,1231,
.dw 2496,2356,3328,1090,15,2363,3328,1231,
.dw 2496,1988,3331,1218,15,1995,3332,1231,
.dw 15,1876,3744,1090,15,1883,3744,1231,
.dw 2505,1876,3744,1154,15,1883,3744,1231,
.dw 1872,1876,3744,1103,15,1882,3745,1231,
.dw 1872,15,3136,1039,15,15,3137,1231,
.dw 15,2100,3328,1103,15,2107,3329,1231,
.dw 1881,2100,3744,1167,15,2107,3748,1231,
.dw 2096,2100,4208,1167,15,2106,4208,1231,
.dw 2096,15,4208,1167,15,15,4208,1231,
; Pattern 7:
.dw 15,2356,3744,1218,15,2363,3744,1039,
.dw 15,2356,3747,1026,15,2363,3748,1039,
.dw 2352,2355,3744,1167,15,2355,3744,1231,
.dw 2352,2355,3744,1090,15,2356,3745,1039,
.dw 15,2356,3744,1154,15,2363,3744,1231,
.dw 2361,2356,3744,1039,15,2363,3744,1231,
.dw 2352,2355,3744,1231,15,2355,3744,1231,
.dw 2352,2355,3744,1167,15,2355,3744,1039,
.dw 2496,2355,3744,1103,2510,2355,3744,1039,
.dw 2511,2355,3747,1167,2511,2356,3754,1039,
.dw 3136,6291,3744,1039,3150,6292,3744,1039,
.dw 3151,6291,3744,1103,3151,6291,3745,1039,
.dw 3136,6297,4208,1026,3150,6297,4209,1039,
.dw 3151,6303,4720,1218,3151,6303,4724,1039,
.dw 3151,4995,4992,1103,3151,4996,4993,1039,
.dw 2496,4995,4208,1026,2511,4995,4209,1039,
.dw 2800,5001,4720,1026,2814,5001,4720,1039,
.dw 2815,5007,4723,1231,2815,5007,4724,1039,
.dw 2800,5603,4720,1154,2814,5604,4720,1039,
.dw 2815,5603,4720,1090,2815,5603,4721,-31729,
.dw 2496,5615,4992,1026,2510,5615,4992,1039,
.dw 2511,5615,4992,1231,2511,5615,4992,1039,
.dw 2511,5615,4992,1167,2511,5615,4992,1039,
.dw 2511,5615,4992,1039,2511,5615,4995,1039,
.dw 2511,5615,5001,1167,2511,5615,5001,-31729,
.dw 2511,5615,5001,1231,2511,5615,5001,1039,
.dw 2511,5615,5001,1167,2511,5615,5001,1039,
.dw 2511,5615,5001,1103,2511,5615,5001,1039,
.dw 2511,5615,5001,1167,2511,5615,5001,1039,
.dw 2511,5615,5001,1231,2511,5615,5001,1039,
.dw 2511,5615,5001,1231,2511,5615,5001,1039,
.dw 2511,5615,5001,1231,2511,5615,5001,1039,
; Pattern 8:
.dw 2496,7489,4992,1218,2510,7490,4992,1103,
.dw 2511,3745,4992,1103,2511,3746,4992,1103,
.dw 1872,3137,4992,1154,15,3138,4995,1039,
.dw 1872,3745,5001,1090,15,3746,5006,1039,
.dw 15,2497,5006,1231,15,2498,5006,1039,
.dw 15,3137,5006,1103,15,3138,5006,1039,
.dw 1872,3745,5006,1039,15,3746,5006,1039,
.dw 1872,6289,5006,1231,15,6290,5006,1103,
.dw 15,8417,5006,1167,15,8418,5006,1103,
.dw 15,4209,5006,1231,15,4210,5006,1103,
.dw 2096,3329,5006,1028,15,3330,5006,1103,
.dw 2096,5601,5006,1092,15,5602,5006,1103,
.dw 15,7489,5006,1028,15,7490,5006,1103,
.dw 15,3745,5006,1039,15,3746,5006,1103,
.dw 1872,3137,5006,1092,15,3138,5006,1103,
.dw 1872,3745,5006,1028,15,3746,5006,1103,
.dw 15,4993,5006,1103,15,4994,5006,1103,
.dw 15,3137,5006,1039,15,3138,5006,1103,
.dw 1872,3745,5006,1231,15,3746,5006,1103,
.dw 1872,6289,5006,1167,15,6290,5007,1103,
.dw 15,8417,4992,1028,15,8418,4992,1103,
.dw 15,4209,4992,1039,15,4210,4993,1103,
.dw 2096,3329,4208,1156,15,3330,4208,1103,
.dw 2096,4209,4211,1028,15,4209,4211,-31665,
.dw 15,4209,4211,1231,15,4209,4211,1103,
.dw 15,4209,4211,1039,15,4209,4211,1103,
.dw 15,4209,4211,1231,15,4209,4211,1103,
.dw 15,4209,4211,1167,15,4209,4211,1103,
.dw 15,4209,4211,1231,15,4209,4211,1103,
.dw 15,4209,4211,1039,15,4209,4211,1103,
.dw 15,4209,4211,1039,15,4209,4211,1103,
.dw 15,4209,4211,1039,15,4209,4211,1103,
; Pattern 9:
.dw 2496,15,3744,1218,2511,15,3744,1167,
.dw 4720,15,3744,1167,4735,15,3745,1167,
.dw 3136,3139,3136,1154,3151,3140,3136,1103,
.dw 4720,3139,3139,1090,4735,3139,3140,1039,
.dw 3136,3145,3136,1039,3151,3145,3136,1103,
.dw 4992,3145,3136,1167,5007,3146,3136,1103,
.dw 3744,3139,3136,1103,3759,3140,3136,1103,
.dw 4992,3139,3136,1039,5007,3139,3137,1167,
.dw 3744,3145,4720,1231,3759,3145,4721,1167,
.dw 4992,3145,2496,1039,5007,3146,2500,1167,
.dw 4208,3139,2800,1103,4223,3140,2804,1167,
.dw 4992,3139,2352,1167,5007,3139,2353,1167,
.dw 2496,3145,4208,1103,2511,3145,4208,1167,
.dw 4992,3145,4208,1103,5007,3146,4209,1167,
.dw 4208,4211,3136,1090,4223,4212,3136,1167,
.dw 4992,4211,3139,1026,5007,4211,3140,1167,
.dw 3136,4217,3136,1090,3151,4217,3136,1167,
.dw 4992,4217,3136,1103,5007,4218,3136,1167,
.dw 4208,4211,3136,1218,4223,4212,3136,1167,
.dw 4992,4211,3136,1231,5007,4211,3137,1167,
.dw 3136,4217,4992,1103,3151,4217,4992,1167,
.dw 4992,4217,4992,1103,5007,4218,4993,1167,
.dw 4208,4211,3136,1231,4223,4212,3136,1167,
.dw 4992,4211,3136,1103,5007,4211,3136,-31601,
.dw 3136,4217,3136,1039,3151,4217,3136,1167,
.dw 4992,4223,3136,1103,5007,4223,3136,1167,
.dw 3744,4223,3136,1039,3759,4223,3136,1167,
.dw 4992,4223,3136,1231,5007,4223,3136,1167,
.dw 2496,4223,3136,1039,2511,4223,3136,1167,
.dw 4992,4223,3136,1103,5007,4223,3136,1167,
.dw 3136,4223,3136,1103,3151,4223,3136,1167,
.dw 4992,4223,3136,1103,5006,4223,3136,1167,
; Pattern 10:
.dw 3136,15,4720,1218,3151,15,4720,1231,
.dw 4992,15,4720,1231,5007,15,4721,1231,
.dw 3744,2355,4208,1154,3759,2356,4208,1167,
.dw 4992,2355,4211,1090,5007,2355,4212,1039,
.dw 2496,2355,4208,1026,2511,2355,4208,1167,
.dw 4992,2355,4208,1231,5007,2356,4208,1167,
.dw 3136,2355,4208,1090,3151,2356,4209,1167,
.dw 3744,2355,2800,1103,3759,2355,2801,1231,
.dw 3136,2355,4208,1218,3151,2355,4209,1231,
.dw 3328,2355,2800,1103,3343,2356,2804,1231,
.dw 3744,2355,3136,1167,3759,2356,3146,1231,
.dw 3328,2355,2800,1231,3343,2355,2810,1231,
.dw 3136,2355,3136,1090,3151,2355,3145,1231,
.dw 4992,2355,3145,1090,5007,2356,3146,1231,
.dw 3744,3747,3328,1090,3759,3748,3337,1231,
.dw 4992,3747,3337,1103,5007,3747,3338,1231,
.dw 3744,3747,3744,1090,3759,3747,3744,1231,
.dw 4992,3747,3744,1167,5007,3748,3745,1231,
.dw 3744,3747,4992,1218,3759,3748,4992,1231,
.dw 4992,3747,5001,1039,5007,3747,5002,1231,
.dw 3744,3747,4992,1090,3759,3747,4992,1231,
.dw 4992,3747,4992,1167,5007,3748,4992,1231,
.dw 3744,3747,4992,1039,3759,3748,4992,1231,
.dw 4992,3747,4992,1167,5007,3747,4993,1231,
.dw 3744,3747,6672,1103,3759,3747,6672,1231,
.dw 4992,3747,6672,1167,5007,3748,6673,1231,
.dw 3744,3747,6288,1026,3759,3748,6288,1231,
.dw 4992,3747,6291,1218,5006,3747,6291,-31537,
.dw 5006,3747,6291,1103,5006,3747,6291,1231,
.dw 5006,3747,6291,1167,5006,3748,6291,1231,
.dw 5006,3747,6291,1167,5006,3748,6291,1231,
.dw 5006,3747,6291,1167,5006,3747,6291,1231,
; Pattern 11:
.dw 3536,15,2812,1218,15,15,2812,1039,
.dw 15,3539,2812,1039,15,3540,2812,1039,
.dw 1760,1763,2812,1154,15,1764,2812,1231,
.dw 1760,2355,2812,1167,15,2356,2812,1039,
.dw 15,2355,2812,1026,15,2356,2812,1231,
.dw 15,2803,2812,1039,15,2804,2812,1231,
.dw 15,1763,2812,1167,15,1764,2812,1231,
.dw 15,1395,2812,1167,15,1396,2812,1039,
.dw 15,3539,2812,1039,15,3540,2812,1039,
.dw 15,2803,2812,1167,15,2804,2812,1039,
.dw 1760,1763,2812,1231,15,1764,2812,1039,
.dw 1760,3539,2812,1039,15,3540,2812,1039,
.dw 15,2355,2812,1167,15,2356,2812,1039,
.dw 15,2355,2812,1167,15,2356,2812,1039,
.dw 15,1395,2812,1090,15,1396,2812,1039,
.dw 15,1763,2812,1090,15,1763,2813,1039,
.dw 1248,1763,3148,1090,1262,1763,3148,1039,
.dw 1263,1763,3148,1231,1263,1764,3148,1039,
.dw 1568,3139,3148,1218,1582,3140,3148,1039,
.dw 1583,3139,3148,1103,1583,3139,3148,1039,
.dw 1568,3139,3148,1090,1582,3139,3148,1039,
.dw 1583,3139,3148,1231,1583,3140,3148,1039,
.dw 1583,3139,3148,1103,1583,3140,3148,1039,
.dw 1568,3139,3148,1231,1583,3139,3148,1039,
.dw 1664,3139,3148,1167,1678,3139,3148,1039,
.dw 1679,3139,3148,1231,1679,3140,3148,1039,
.dw 1568,3139,3148,1103,1582,3140,3148,1039,
.dw 1583,3139,3148,1039,1583,3139,3148,1039,
.dw 1664,3139,3148,1091,1679,3139,3148,1219,
.dw 1568,3139,3148,1154,1583,3140,3149,1039,
.dw 1872,3139,3758,1154,1887,3140,3758,1039,
.dw 1568,3139,3758,1154,1582,3139,3758,1039,
; Pattern 12:
.dw 15,15,3148,1218,15,15,3148,1103,
.dw 15,4723,3148,1103,15,4724,3148,1103,
.dw 2352,2355,3148,1154,15,2356,3148,1039,
.dw 2352,3139,3148,1231,15,3140,3148,1039,
.dw 15,1571,3148,1026,15,1572,3148,1039,
.dw 15,3971,3148,1103,15,3972,3148,1039,
.dw 2352,2099,3148,1231,15,2100,3148,1039,
.dw 2352,1987,3148,1231,15,1988,3149,1103,
.dw 15,4723,2364,1103,15,4724,2364,1103,
.dw 15,3139,2364,1231,15,3140,2364,1103,
.dw 2352,2355,2364,1039,15,2356,2364,1103,
.dw 2352,3971,2364,1103,15,3972,2364,1103,
.dw 15,1571,2364,1231,15,1572,2364,1103,
.dw 15,3139,2364,1231,15,3140,2364,1103,
.dw 2352,1987,2364,1090,15,1988,2364,1103,
.dw 15,2355,2364,1090,15,2355,2365,1103,
.dw 1392,2355,2108,1090,1406,2355,2108,1103,
.dw 1407,2355,2108,1039,1407,2356,2108,1103,
.dw 1664,4211,2108,1218,1678,4212,2108,1103,
.dw 1679,4211,2108,1167,1679,4211,2108,1103,
.dw 1664,4211,2108,1090,1678,4211,2108,1103,
.dw 1679,4211,2108,1039,1679,4212,2108,1103,
.dw 1679,4211,2108,1167,1679,4212,2108,1103,
.dw 1664,4211,2108,1039,1679,4211,2108,1103,
.dw 1872,4211,2108,1231,1886,4211,2108,1103,
.dw 1887,4211,2108,1039,1887,4212,2108,1103,
.dw 1664,4211,2108,1167,1678,4212,2108,1103,
.dw 1679,4211,2108,1103,1679,4211,2108,1103,
.dw 1872,4211,2108,1167,1887,4211,2108,1039,
.dw 1664,4211,2108,1231,1679,4212,2108,1103,
.dw 2096,4211,2108,1154,2110,4212,2108,1103,
.dw 2111,4211,2108,1154,2111,4211,2108,1103,
; Pattern 13:
.dw 1872,4724,3744,1218,1886,15,3744,1167,
.dw 1887,15,3747,1167,1887,15,3748,1167,
.dw 1872,6291,3744,1154,15,6292,3745,1103,
.dw 1872,3139,3136,1218,15,3140,3137,1039,
.dw 15,4211,3328,1103,15,4212,3332,1103,
.dw 15,5603,3744,1167,15,5604,3745,1103,
.dw 2096,6675,4208,1218,15,6676,4208,1103,
.dw 2096,3331,4208,1218,15,3332,4209,1167,
.dw 15,3139,3744,1090,15,3140,3744,1167,
.dw 15,6291,3744,1218,15,6292,3744,1167,
.dw 2352,3139,3744,1103,15,3139,3744,1167,
.dw 2352,3139,3744,1090,15,3139,3744,1167,
.dw 2496,3139,3744,1218,2511,3139,3745,1167,
.dw 4208,3139,3753,1039,4223,3140,3754,1167,
.dw 3136,3139,4208,1090,3151,3140,4208,1167,
.dw 4208,3139,4211,1090,4223,3139,4212,1167,
.dw 3136,3139,4208,1167,3151,3139,4209,1167,
.dw 4208,3139,4720,1103,4223,3140,4721,1167,
.dw 3136,3139,4992,1039,3151,3140,4993,1167,
.dw 2496,3139,4208,1231,2511,3139,4212,1167,
.dw 2800,3145,4720,1090,2815,3145,4720,1167,
.dw 4720,3145,4723,1026,4735,3146,4724,1167,
.dw 2800,2803,4720,1231,2815,2804,4720,1167,
.dw 4720,2803,4723,1026,4735,2803,4724,1167,
.dw 3136,2809,4992,1218,3151,2809,4992,1167,
.dw 4992,2809,4992,1103,5007,2810,4992,1167,
.dw 3744,3139,4992,1154,3759,3140,4992,1167,
.dw 4992,3139,4992,1090,5006,3139,4992,1167,
.dw 5006,3145,4992,1231,5006,3145,4995,1103,
.dw 5006,3145,5001,1039,5006,3145,5001,-31601,
.dw 5006,3145,5001,1231,5006,3145,5001,1167,
.dw 5006,3145,5001,1231,5006,3145,5001,1167,
; Pattern 14:
.dw 1872,6291,3744,1039,15,6292,3744,1231,
.dw 1872,3139,3747,1231,15,3140,3748,1231,
.dw 15,3747,3744,1231,15,3748,3744,1167,
.dw 1881,4995,3744,1039,15,4996,3744,1039,
.dw 1872,3747,3744,1090,15,3748,3745,1167,
.dw 1872,3747,3136,1154,15,3748,3137,1167,
.dw 15,4211,3328,1218,15,4212,3332,1167,
.dw 1881,2803,3744,1218,15,2804,3745,1231,
.dw 2096,3747,4208,1167,15,3748,4208,1231,
.dw 2096,2499,4208,1218,15,2500,4209,1231,
.dw 15,2355,3744,1090,15,2356,3744,1231,
.dw 2105,3139,3744,1167,15,3140,3744,1231,
.dw 2352,3747,3744,1218,15,3747,3744,1231,
.dw 2352,3753,3744,1026,15,3753,3744,1231,
.dw 2352,3759,3744,1167,2367,3759,3744,1231,
.dw 3136,3759,3744,1167,3151,3759,3744,1231,
.dw 2352,4723,3747,1231,2367,4724,3754,1231,
.dw 2096,4723,3328,1167,2111,4723,3329,1231,
.dw 2496,4729,3136,1026,2511,4729,3136,1231,
.dw 3136,4729,3139,1218,3151,4730,3140,1231,
.dw 2496,4995,3136,1167,2511,4996,3136,1231,
.dw 3136,4995,3136,1026,3151,4995,3137,1231,
.dw 2352,5001,2800,1218,2367,5001,2800,1231,
.dw 2800,5001,2800,1103,2815,5002,2800,1231,
.dw 2352,4723,2800,1218,2367,4724,2800,1231,
.dw 2800,4723,2800,1090,2815,4724,2801,1231,
.dw 2096,2804,3328,1154,2111,2813,3328,1231,
.dw 3328,2804,3328,1090,3343,2813,3328,1231,
.dw 2800,2804,3328,1039,2814,2813,3329,1167,
.dw 2814,2804,3136,1103,2814,2813,3137,1231,
.dw 2814,2803,3328,1039,2814,2803,3332,1231,
.dw 2814,2803,3744,1039,2814,2803,3744,-31537,
; Pattern 15:
.dw 15,2500,3136,1026,15,2507,3136,1039,
.dw 15,2500,3136,1218,15,2507,3137,1039,
.dw 1568,2500,3136,1039,15,2507,3136,1231,
.dw 1568,2506,3136,1026,15,15,3137,1039,
.dw 15,1988,3328,1090,15,1995,3328,1231,
.dw 15,1988,3328,1231,15,1995,3328,1231,
.dw 2496,1988,3328,1218,15,1995,3328,1231,
.dw 2496,1994,3328,1218,15,15,3329,1039,
.dw 15,1876,3744,1154,15,1883,3744,1039,
.dw 15,1876,3744,1218,15,1883,3744,1039,
.dw 1872,1876,3744,1167,15,1883,3745,1039,
.dw 1872,1875,3136,1231,15,1875,3137,1039,
.dw 15,1875,3328,1039,15,1875,3332,1039,
.dw 15,1875,3744,1103,15,1876,3745,1039,
.dw 2096,2100,4208,1231,15,2107,4209,1039,
.dw 2096,2100,3328,1231,15,2107,3338,1039,
.dw 15,2500,3136,1218,15,2507,3136,1039,
.dw 15,2500,3139,1154,15,2507,3140,1039,
.dw 1568,2500,3136,1103,15,2507,3136,1039,
.dw 1568,2506,3139,1218,15,15,3140,1039,
.dw 15,1995,3328,1154,15,1988,3328,1039,
.dw 15,1995,3328,1103,15,1988,3329,1039,
.dw 1248,1995,3328,1218,15,1994,3328,1039,
.dw 1248,15,3328,1090,15,15,3329,1039,
.dw 15,1876,3744,1218,15,1883,3744,1039,
.dw 15,1876,3744,1090,15,1883,3744,1039,
.dw 1872,1876,3744,1231,15,1883,3745,1039,
.dw 1872,1875,3136,1167,15,1875,3137,1039,
.dw 15,1875,3328,1103,15,1875,3329,1231,
.dw 15,1875,3744,1167,15,1876,3748,1039,
.dw 2096,2100,4208,1103,15,2107,4208,1039,
.dw 2096,2100,4208,1103,15,2106,4208,1039,
; Pattern 16:
.dw 15,2356,3744,1026,15,2363,3744,1103,
.dw 15,2356,3747,1218,15,2363,3748,1103,
.dw 2352,2356,3744,1103,15,2363,3744,1039,
.dw 2352,2356,3747,1026,15,2363,3748,1039,
.dw 1872,1772,3744,1090,1886,15,3744,1039,
.dw 1887,15,3744,1039,1887,15,3744,1039,
.dw 2096,15,3744,1039,2111,15,3744,1039,
.dw 2352,15,3744,1039,2367,15,3744,1103,
.dw 2496,3139,3744,1154,2510,3139,3744,1103,
.dw 2511,3139,3744,1218,2511,3140,3745,1103,
.dw 3136,3139,4208,1231,3151,3140,4208,1103,
.dw 4208,3139,4211,1218,4223,3139,4212,1103,
.dw 2800,3139,4720,1026,2815,3139,4721,1103,
.dw 4208,3139,4992,1167,4223,3140,4993,1103,
.dw 2800,2803,4720,1218,2815,2804,4720,1103,
.dw 3744,2803,4723,1218,3759,2803,4724,1103,
.dw 3136,2803,4992,1218,3150,2804,4992,1103,
.dw 3151,7491,4992,1231,3151,7492,4992,1103,
.dw 1872,4211,4992,1090,15,4212,4992,1103,
.dw 1872,3747,4992,1218,15,3748,4992,1103,
.dw 15,3331,4992,1231,15,3332,4995,1103,
.dw 15,7491,5001,1167,15,7492,5007,1103,
.dw 1872,5603,3744,1039,15,5604,3744,1103,
.dw 1872,2803,3747,1167,15,2804,3748,1103,
.dw 15,2500,3744,1039,15,2507,3744,1103,
.dw 15,2500,3744,1167,15,2507,3744,1103,
.dw 1872,2500,3744,1039,15,2507,3745,1103,
.dw 1872,2500,3136,1231,15,2507,3137,1103,
.dw 15,2504,3328,1167,15,15,3329,1039,
.dw 15,2808,3744,1231,15,15,3745,1103,
.dw 2096,15,4208,1090,15,15,4208,1103,
.dw 2096,3144,4208,1090,15,15,4208,1103,
; Pattern 17:
.dw 15,3140,3744,1026,15,3147,3744,1167,
.dw 15,3140,3747,1218,15,3147,3748,1167,
.dw 2352,3140,3744,1167,15,3147,3744,1103,
.dw 2352,3140,3747,1026,15,3147,3748,1039,
.dw 3136,3146,3744,1090,3151,15,3744,1103,
.dw 3744,15,3744,1103,3759,15,3744,1103,
.dw 2496,15,3744,1103,2511,15,3745,1103,
.dw 3136,15,3136,1103,3151,15,3137,1167,
.dw 2096,15,2800,1154,2111,15,2801,1167,
.dw 2800,15,3136,1218,2815,15,3140,1167,
.dw 4208,5603,3328,1039,4223,5604,3329,1167,
.dw 3328,5603,2800,1218,3343,5603,2801,1167,
.dw 3744,5603,3136,1026,3759,5603,3137,1167,
.dw 3136,5603,3744,1231,3151,5603,3748,1167,
.dw 3328,5603,3328,1218,3342,5603,3328,1167,
.dw 3343,5615,3328,1218,3343,5615,3329,1167,
.dw 3744,5615,3744,1218,3758,5615,3744,1167,
.dw 3759,5615,3744,1039,3759,5615,3744,1167,
.dw 3759,5615,3744,1167,3759,5615,3744,1167,
.dw 3759,5615,3744,1039,3759,5615,3744,1167,
.dw 3759,5615,3744,1039,3759,5615,3744,1167,
.dw 3759,5615,3744,1231,3759,5615,3744,1167,
.dw 3759,5615,3744,1103,3759,5615,3759,1167,
.dw 3759,5615,3759,1231,3759,5615,3759,1167,
.dw 3759,5615,3759,1103,3759,5615,3759,1167,
.dw 3759,5615,3759,1231,3759,5615,3759,1167,
.dw 3759,5615,3759,1103,3759,5615,3759,1167,
.dw 3759,5615,3759,1039,3759,5615,3759,1167,
.dw 3759,5615,3759,1231,3759,5615,3759,1103,
.dw 3759,5615,3759,1039,3759,5615,3759,1167,
.dw 3759,5615,3759,1167,3759,5615,3759,1167,
.dw 3759,5615,3759,1167,3759,5615,3759,1167,
; Pattern 18:
.dw 15,3136,15,1026,15,3136,15,1231,
.dw 15,3136,6291,1039,15,3136,6303,1231,
.dw 15,3136,3139,1154,15,3137,3151,1167,
.dw 4720,3136,4211,1103,15,3137,4222,1039,
.dw 15,2640,4223,1091,15,2640,4223,1167,
.dw 15,2640,6291,1167,15,2641,6303,1167,
.dw 4720,2096,3139,1167,15,2096,3151,1167,
.dw 15,2096,4211,1167,15,2097,4222,1231,
.dw 15,2224,4223,1231,15,2224,4223,1231,
.dw 15,2224,5603,1039,15,2225,5615,1231,
.dw 4720,2224,2803,1026,15,2224,2815,1231,
.dw 4720,2224,3747,1039,15,2225,3758,1231,
.dw 3139,2800,3759,1103,3139,2800,3759,1231,
.dw 3139,2800,5603,1039,3140,2800,5615,1231,
.dw 4720,2800,2803,1218,15,2800,2815,1231,
.dw 15,2800,3747,1039,15,2801,3758,1231,
.dw 3139,3968,3759,1039,3139,3968,3759,1231,
.dw 3139,3968,6291,1103,3140,3969,6303,1231,
.dw 4720,3968,3139,1154,15,3968,3151,1231,
.dw 3139,3968,3971,1103,3139,3969,3982,1231,
.dw 3139,3968,3982,1026,3139,3968,3983,1231,
.dw 3139,3968,6291,1039,3140,3968,6303,1231,
.dw 4720,3968,3139,1167,15,3968,3151,1231,
.dw 15,3968,3971,1039,15,3969,3982,1231,
.dw 3328,4208,3983,1167,3328,4208,3983,1231,
.dw 3328,4208,8419,1039,3328,4209,8431,1231,
.dw 3328,4208,3331,1088,3329,4208,3343,1231,
.dw 4720,4208,4211,1026,15,4209,4222,1231,
.dw 15,4208,4222,1218,15,4208,4223,1167,
.dw 15,4208,8419,1103,15,4208,8431,1231,
.dw 4720,4208,3331,1154,15,4208,3343,1231,
.dw 15,4208,4211,1231,15,4208,4222,1231,
; Pattern 19:
.dw 15,3136,15,1026,15,3136,15,1039,
.dw 15,3136,6291,1103,15,3136,6303,1039,
.dw 15,3136,3139,1154,15,3137,3151,1231,
.dw 4720,3136,4211,1167,15,3137,4222,1039,
.dw 15,2640,4223,1091,15,2640,4223,1231,
.dw 15,2640,6291,1231,15,2641,6303,1231,
.dw 4720,2096,3139,1231,15,2096,3151,1231,
.dw 15,2096,4211,1231,15,2097,4222,1039,
.dw 15,1872,4223,1039,15,1872,4223,1039,
.dw 15,1872,5603,1103,15,1873,5615,1039,
.dw 4720,1872,2803,1026,15,1872,2815,1039,
.dw 4720,1872,3747,1103,15,1873,3758,1039,
.dw 3139,2224,3759,1167,3139,2224,3759,1039,
.dw 3139,2224,5603,1103,3140,2224,5615,1039,
.dw 4720,2224,2803,1218,15,2224,2815,1039,
.dw 15,2224,3747,1103,15,2225,3758,1039,
.dw 3139,4720,3759,1103,3139,4720,3759,1039,
.dw 3139,4720,6291,1167,3140,4721,6303,1039,
.dw 4720,4720,3139,1154,15,4720,3151,1039,
.dw 3139,4720,3971,1167,3139,4721,3982,1039,
.dw 3139,4720,3982,1026,3139,4720,3983,1039,
.dw 3139,4720,6291,1103,3140,4721,6303,1039,
.dw 4720,4720,3139,1231,15,4720,3151,1039,
.dw 15,4720,3971,1103,15,4721,3982,1039,
.dw 3331,4208,3983,1231,3331,4208,3983,1039,
.dw 3331,4208,8419,1103,3331,4208,8431,1039,
.dw 3331,4208,3331,1088,3332,4208,3343,1039,
.dw 4720,4208,4211,1026,15,4208,4222,1039,
.dw 15,4208,4222,1218,15,4208,4223,1231,
.dw 15,4208,8419,1167,15,4208,8431,1039,
.dw 4720,4208,3331,1154,15,4208,3343,1039,
.dw 15,4208,4211,1039,15,4208,4222,1039,
; Pattern 20:
.dw 15,3136,15,1026,15,3136,15,1103,
.dw 15,3136,6291,1167,15,3136,6303,1103,
.dw 15,3136,3139,1154,15,3137,3151,1039,
.dw 4720,3136,4211,1231,15,3137,4222,1039,
.dw 15,2640,4223,1091,15,2640,4223,1039,
.dw 15,2640,6291,1039,15,2641,6303,1039,
.dw 4720,2096,3139,1039,15,2096,3151,1039,
.dw 15,2096,4211,1039,15,2097,4222,1103,
.dw 15,2224,4223,1103,15,2224,4223,1103,
.dw 15,2224,5603,1167,15,2225,5615,1103,
.dw 4720,2224,2803,1026,15,2224,2815,1103,
.dw 4720,2224,3747,1167,15,2225,3758,1103,
.dw 3139,2800,3759,1231,3139,2800,3759,1103,
.dw 3139,2800,5603,1167,3140,2800,5615,1103,
.dw 4720,2800,2803,1218,15,2800,2815,1103,
.dw 15,2800,3747,1167,15,2801,3758,1103,
.dw 3968,4720,3759,1167,3968,4720,3759,1103,
.dw 3968,4720,6291,1231,3969,4721,6303,1103,
.dw 4720,4720,3139,1154,15,4720,3151,1103,
.dw 3968,4720,3971,1231,3968,4721,3982,1103,
.dw 3968,4720,3982,1026,3968,4720,3983,1103,
.dw 3968,4720,6291,1167,3969,4721,6303,1103,
.dw 4720,5296,3139,1039,15,5296,3151,1103,
.dw 15,5296,3971,1167,15,5297,3982,1103,
.dw 4208,6288,3983,1039,4208,6288,3983,1103,
.dw 4208,6288,6291,1167,4208,6288,6303,1103,
.dw 4208,6288,3139,1088,4209,6289,3151,1103,
.dw 4720,6288,4211,1026,15,6289,4222,1103,
.dw 15,6288,4222,1218,15,6288,4223,1039,
.dw 15,6288,6291,1231,15,6288,6303,1103,
.dw 4720,6288,3139,1154,15,6288,3151,1103,
.dw 15,6288,4211,1103,15,6288,4222,1103,
; Pattern 21:
.dw 15,3136,15,1026,15,3136,15,1167,
.dw 15,3136,6291,1231,15,3137,6303,1167,
.dw 15,3136,3139,1231,15,3136,3151,1103,
.dw 3968,3136,4212,1039,3969,3137,4734,1039,
.dw 4720,2800,15,1090,15,2800,15,1103,
.dw 15,2800,6291,1103,15,2801,6303,1103,
.dw 15,2640,3139,1026,15,2640,3151,1103,
.dw 15,2640,4211,1103,15,2641,4222,1167,
.dw 4208,2800,4223,1167,4208,2800,4223,1167,
.dw 4208,2800,5603,1231,4209,2801,5615,1167,
.dw 4720,3328,2803,1103,15,3328,2815,1167,
.dw 4720,3328,3747,1231,15,3329,3758,1167,
.dw 4208,4208,3759,1218,4208,4208,3759,1167,
.dw 4208,4208,5603,1231,4209,4209,5615,1167,
.dw 4720,4208,2803,1218,15,4208,2815,1167,
.dw 15,4208,3747,1231,15,4209,3758,1167,
.dw 15,4720,3759,1155,15,4720,3759,1167,
.dw 15,4720,7955,1039,15,4720,7967,1167,
.dw 4720,4720,3971,1155,15,4721,3983,1167,
.dw 4720,4720,7955,1219,15,4721,7966,1167,
.dw 15,4208,7966,1026,15,4208,7967,1167,
.dw 15,4208,7955,1231,15,4209,7967,1167,
.dw 4720,3968,3971,1027,15,3968,3983,1167,
.dw 15,3968,3971,1231,15,3969,3982,1167,
.dw 15,4208,3983,1027,15,4208,3983,1167,
.dw 15,4208,8419,1231,15,4208,8431,1167,
.dw 4720,4208,3331,1167,15,4208,3343,1167,
.dw 4720,4208,4211,1027,15,4209,4222,1167,
.dw 15,4208,4222,1218,15,4208,4223,1103,
.dw 15,4208,8419,1039,15,4208,8431,1167,
.dw 4720,4208,3331,1155,15,4209,3343,1167,
.dw 15,4208,4211,1167,15,4208,4222,1167,
; Pattern 22:
.dw 4723,4720,15,1103,4723,4720,15,1231,
.dw 4723,4720,9459,1039,4723,4720,9471,1231,
.dw 4723,4720,4723,1218,4724,4721,4735,1167,
.dw 4720,4720,4723,1024,4721,4721,4734,1039,
.dw 4720,4208,4734,1090,15,4208,4735,1167,
.dw 15,4208,9459,1167,15,4209,9471,1167,
.dw 15,3968,4723,1026,15,3968,4735,1167,
.dw 15,3968,4723,1167,15,3969,4734,1231,
.dw 4211,4208,4735,1231,4211,4208,4735,1231,
.dw 4211,4208,8419,1039,4211,4208,8431,1231,
.dw 4211,4208,4211,1090,4212,4208,4223,1231,
.dw 4208,4208,4211,1039,4209,4209,4222,1231,
.dw 4211,4208,4222,1218,4211,4209,4223,1231,
.dw 4211,4720,8419,1039,4212,4721,8431,1231,
.dw 4720,5296,3971,1039,15,5297,3983,1231,
.dw 15,5600,4211,1039,15,5601,4222,1231,
.dw 5299,6288,4223,1152,5299,6288,4223,1231,
.dw 5299,6288,6291,1103,5300,6288,6303,1231,
.dw 4720,6288,3139,1154,15,6288,3151,1231,
.dw 4720,6288,4211,1039,15,6288,4222,1231,
.dw 15,6288,4222,1026,15,6288,4223,1231,
.dw 15,6288,6291,1039,15,6289,6303,1231,
.dw 4720,6288,3139,1103,15,6289,3151,1231,
.dw 15,4208,4211,1039,15,4209,4222,1231,
.dw 15,3136,4223,1026,15,3136,4223,1231,
.dw 15,3136,6291,1218,15,3137,6303,1231,
.dw 4720,3136,3139,1231,15,3136,3151,1231,
.dw 4720,3136,4211,1026,15,3137,4222,1231,
.dw 15,3328,4222,1218,15,3328,4223,1167,
.dw 15,3328,6291,1103,15,3329,6303,1231,
.dw 4720,3328,3139,1231,15,3328,3151,1231,
.dw 15,3328,4211,1231,15,3328,4222,1231,
; Pattern 23:
.dw 15,3136,15,1090,15,3136,15,1039,
.dw 15,3136,6291,1103,15,3136,6303,1039,
.dw 4720,3136,3139,1218,15,3136,3151,1231,
.dw 3136,3136,4212,1103,3136,3136,4734,1039,
.dw 3136,3136,15,1090,3139,3136,15,1231,
.dw 3139,3136,6291,1231,3140,3136,6303,1231,
.dw 3136,3136,3139,1103,3136,3136,3151,1231,
.dw 3136,3136,4211,1231,3139,3136,4222,1039,
.dw 3139,3136,4223,1218,3139,3136,4223,1039,
.dw 3139,3136,6291,1103,3140,3137,6303,1039,
.dw 4720,3136,3139,1167,15,3136,3151,1039,
.dw 4720,3136,4211,1026,15,3136,4222,1039,
.dw 15,3136,4223,1218,15,3137,4223,1039,
.dw 15,3136,6291,1103,15,3136,6303,1039,
.dw 4720,3136,3139,1026,15,3136,3151,1039,
.dw 15,3136,4211,1103,15,3137,4222,1039,
.dw 15,3136,4223,1154,15,3136,4223,1039,
.dw 15,3136,6291,1167,15,3136,6303,1039,
.dw 4720,3136,3139,1154,15,3137,3151,1039,
.dw 4720,3136,4211,1103,15,3136,4222,1039,
.dw 15,3136,4222,1026,15,3136,4223,1039,
.dw 15,3136,6291,1103,15,3136,6303,1039,
.dw 4720,3136,3139,1167,15,3136,3151,1039,
.dw 15,3136,4211,1103,15,3136,4222,1039,
.dw 15,3136,4223,1026,15,3151,4223,1039,
.dw 15,3151,6291,1039,15,3151,6303,1039,
.dw 4720,3136,3139,1039,15,3136,3151,1039,
.dw 4720,3136,4211,1026,15,3139,4222,1039,
.dw 15,3139,4222,1218,15,3140,4223,1231,
.dw 15,3136,6291,1167,15,3136,6303,1039,
.dw 4720,3136,3139,1218,15,3139,3151,1039,
.dw 15,3139,4211,1039,15,3139,4222,1039,
; Pattern 24:
.dw 6290,15,15,1088,6290,15,15,1103,
.dw 6290,15,6288,1167,6291,15,6289,1103,
.dw 3138,15,3139,1039,3138,15,3140,1039,
.dw 3138,15,4217,1088,3139,15,4217,1039,
.dw 4210,15,4217,1088,4210,15,4218,1039,
.dw 4210,15,6300,1039,4211,15,6301,1039,
.dw 5298,15,3149,1167,5298,15,3150,1039,
.dw 5298,15,4222,1039,5299,15,4222,1103,
.dw 6290,15,4222,1039,6290,15,4223,1103,
.dw 6290,15,4223,1167,6290,15,4223,1103,
.dw 6290,15,4223,1231,6290,15,4223,1103,
.dw 6290,15,4223,1103,6290,15,4223,1103,
.dw 6290,15,4223,1039,6290,15,4223,1103,
.dw 6290,15,4223,1167,6290,15,4223,1103,
.dw 6290,15,4223,1103,6290,15,4223,1103,
.dw 6290,15,4223,1167,6290,15,4223,1103,
.dw 6302,15,4223,1231,6303,15,4223,1103,
.dw 6303,15,4223,463,6303,15,4223,335,
.dw 6303,15,4223,463,6303,15,4223,335,
.dw 6303,15,4223,399,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,399,6303,15,4223,335,
.dw 6303,15,4223,463,6303,15,4223,335,
.dw 6303,15,4223,399,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,271,6303,15,4223,271,
.dw 6303,15,4223,463,6303,15,4223,335,
.dw 6303,15,4223,271,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,335,
; Pattern 25:
.dw 7074,7076,7076,1095,7074,15,7076,1167,
.dw 7074,15,7076,1164,7075,15,7077,1167,
.dw 3538,4727,7076,1036,3539,15,7077,1103,
.dw 3538,3543,3540,1095,3538,15,3540,1039,
.dw 3538,3542,3540,1100,3538,15,3541,1103,
.dw 3538,3543,7076,1031,3538,15,7077,1103,
.dw 3538,3542,3540,1159,3538,15,3540,1103,
.dw 3538,15,3541,1038,3539,15,4733,1167,
.dw 7074,15,3145,1031,7075,15,4213,1167,
.dw 3538,7076,4724,1159,3538,15,15,1167,
.dw 3538,15,15,1223,3539,15,15,1167,
.dw 7074,15,15,1167,7075,15,15,1167,
.dw 7490,7076,7492,1031,7490,15,7492,1167,
.dw 7490,15,7492,1162,7491,15,7493,1167,
.dw 3746,15,7492,1098,3747,15,7493,1167,
.dw 3746,15,3748,1159,3746,15,3748,1167,
.dw 3746,15,3748,1226,3746,15,3749,1167,
.dw 3746,15,7492,1223,3746,15,7493,1167,
.dw 3746,15,3748,1223,3746,15,3748,1167,
.dw 3746,15,3748,1165,3747,15,3749,1167,
.dw 7490,15,3141,1095,7491,15,3149,1167,
.dw 3746,15,3145,1159,3746,15,3141,1167,
.dw 3746,15,3749,1223,3747,15,4997,1167,
.dw 7490,15,7076,1159,7490,15,15,-31601,
.dw 7490,15,15,1167,7490,15,15,1167,
.dw 7490,15,15,1167,7490,15,15,1167,
.dw 7490,15,15,1167,7490,15,15,1167,
.dw 7490,15,15,1167,7490,15,15,1167,
.dw 7490,15,15,1103,7490,15,15,1103,
.dw 7490,15,15,1039,7490,15,15,1167,
.dw 7490,15,15,1103,7490,15,15,1167,
.dw 7490,15,15,1167,7490,15,15,1167,
; Pattern 26:
.dw 4721,4723,9459,1862,4721,4724,9460,1999,
.dw 4722,4724,9460,1999,6290,4723,4723,1926,
.dw 4722,4724,4724,1871,4210,4723,4724,1863,
.dw 3969,4723,7955,1862,3969,4724,7955,1807,
.dw 3970,4724,7956,1935,4209,4723,6291,1862,
.dw 4209,4724,6291,1871,4210,4723,6291,1863,
.dw 4721,4723,6291,1926,4721,4724,6292,1935,
.dw 4722,5940,7076,1871,6290,5939,3539,1926,
.dw 4722,5940,3540,1871,3970,5939,3540,1927,
.dw 3137,5939,5939,1926,3137,5940,5939,1999,
.dw 3138,5940,5940,1807,3537,5939,4723,1926,
.dw 3537,5940,4723,1999,3538,5939,4723,1927,
.dw 3969,5939,4723,1798,3969,5940,4724,1999,
.dw 3969,4724,9460,1999,3969,4723,4723,1926,
.dw 3969,4724,4724,1935,3970,4723,4724,1927,
.dw 3137,4723,7955,1926,3137,4724,7955,1999,
.dw 3137,4724,7956,1807,3137,4723,6291,1926,
.dw 3138,4724,6291,1807,4722,4723,6291,1927,
.dw 4465,4723,6291,1990,4466,4724,6292,1999,
.dw 3970,4996,8932,1999,3537,4995,4467,1926,
.dw 3538,4996,4468,1935,2497,4995,4468,1927,
.dw 2497,4995,7075,1926,2497,4996,7075,1999,
.dw 2497,4996,7076,1807,2497,4995,5939,1926,
.dw 2497,4996,5939,1999,2497,4995,5939,-30841,
.dw 2497,4995,5939,-30842,2497,4995,5939,-30769,
.dw 2497,4995,5939,1999,2497,4995,5939,1999,
.dw 2497,4995,5939,1999,2497,4995,5939,1999,
.dw 2497,4995,5939,1999,2497,4995,5939,1999,
.dw 2497,4995,5939,1935,2497,4995,5939,1935,
.dw 2497,4995,5939,1871,2497,4995,5939,1999,
.dw 2497,4995,5939,1935,2497,4995,5939,1999,
.dw 2497,4995,5939,1999,2497,4995,5939,1999,
; Pattern 27:
.dw 4721,15,15,1862,4721,15,15,1807,
.dw 4722,4724,9460,1807,6290,4723,4723,1926,
.dw 4722,4724,4724,1935,4210,4723,4724,1863,
.dw 3969,4723,7955,1862,3969,4724,7955,1807,
.dw 3970,4724,7956,1999,4209,4723,6291,1862,
.dw 4209,4724,6291,1935,4210,4723,6291,1863,
.dw 4721,4723,6291,1926,4721,4724,6292,1999,
.dw 4722,5940,5939,1935,6290,5939,5943,1926,
.dw 4722,5940,5944,1935,3970,5939,3331,1927,
.dw 3137,5939,3335,1926,3137,5940,3336,1807,
.dw 3138,5940,3540,1871,3537,5939,3971,1926,
.dw 3537,5940,3971,1807,3538,5939,3971,1927,
.dw 3969,5939,3971,1798,3970,5940,3972,1807,
.dw 3137,6292,6291,1807,3137,6291,6299,1926,
.dw 3137,6292,6300,1999,3138,6291,6291,1927,
.dw 2353,6291,6299,1926,2354,6292,6300,1807,
.dw 1985,6292,6291,1871,1985,6291,6291,1926,
.dw 1985,6292,6291,1871,1986,6291,6291,-30841,
.dw 2353,6291,6291,-30778,2353,6292,6292,1807,
.dw 2353,4996,4724,-30961,2353,4995,4723,-30842,
.dw 2353,4996,4723,1999,2353,4995,4723,1927,
.dw 2353,4995,4723,1926,2353,4996,4723,1807,
.dw 2353,4996,4723,1871,2353,4995,4723,1926,
.dw 2353,4996,4723,1807,2353,4995,4723,1927,
.dw 2353,4995,4723,-30842,2353,4995,4723,-30961,
.dw 2353,4995,4723,1807,2353,4995,4723,1807,
.dw 2353,4995,4723,1807,2353,4995,4723,1807,
.dw 2353,4995,4723,1807,2353,4995,4723,1807,
.dw 2353,4995,4723,1999,2353,4995,4723,1999,
.dw 2353,4995,4723,1935,2353,4995,4723,1807,
.dw 2353,4995,4723,1999,2353,4995,4723,1807,
.dw 2353,4995,4723,1807,2353,4995,4723,1807,
; Pattern 28:
.dw 2353,3968,15,1862,2353,3969,15,1871,
.dw 2353,4721,4724,1871,2353,3328,7955,1926,
.dw 2353,3329,7960,1999,2353,3137,7956,1863,
.dw 2353,3968,6291,1862,2353,3969,6291,1807,
.dw 2354,4721,6292,1807,4720,3328,4723,1862,
.dw 4721,3329,4723,1999,4720,3137,4723,1863,
.dw 4720,3968,4723,1926,4720,3969,4724,1807,
.dw 4720,4721,5939,1999,4720,3536,5939,1926,
.dw 4720,3537,5940,1999,4720,3329,5940,1927,
.dw 4720,3968,7955,1926,4720,3969,7955,1871,
.dw 4720,4721,7956,1935,4720,3536,5939,1926,
.dw 4720,3537,5939,1871,4720,3329,5939,1927,
.dw 4720,3968,5939,1798,4720,3969,5940,1871,
.dw 4720,4721,9459,1871,4720,3328,9459,1926,
.dw 4720,3329,9460,1807,4720,3137,9460,1927,
.dw 4720,3968,7955,1926,4720,3969,7955,1871,
.dw 4721,4721,7956,1935,4720,3328,6291,1926,
.dw 4721,3329,6291,1935,4720,3137,6291,1927,
.dw 4720,3968,6291,1990,4720,3969,6291,1871,
.dw 4720,4721,6292,1871,4720,3536,5939,1926,
.dw 4720,3537,5940,1807,4720,3329,5940,1927,
.dw 4720,3968,7955,1926,4720,3969,7955,1871,
.dw 4720,4721,7956,1935,4720,3536,5939,1926,
.dw 4720,3537,5939,1871,4720,3329,5939,-30841,
.dw 4720,3968,5939,1926,4720,3968,5939,1871,
.dw 4720,3968,5939,-30897,4720,3968,5939,1871,
.dw 4720,3968,5939,1871,4720,3968,5939,1871,
.dw 4720,3968,5939,1871,4720,3968,5939,1871,
.dw 4720,3968,5939,1807,4720,3968,5939,1807,
.dw 4720,3968,5939,1999,4720,3968,5939,1871,
.dw 4720,3968,5939,1807,4720,3968,5939,1871,
.dw 4720,3968,5939,1871,4720,3968,5939,1871,
; Pattern 29:
.dw 15,3968,15,1862,15,3969,15,1935,
.dw 15,4721,9459,1935,15,3328,9463,1926,
.dw 15,3329,9464,1807,15,3137,9460,1863,
.dw 15,3968,7955,1862,15,3969,7955,1807,
.dw 15,4721,7956,1871,4720,3328,6291,1862,
.dw 4721,3329,6291,1807,3328,3137,6291,1863,
.dw 3328,3968,6291,1926,3328,3969,6292,1871,
.dw 3328,4721,5939,1807,3328,3536,5943,1926,
.dw 3328,3537,5944,1807,3328,3329,5940,1927,
.dw 3328,3968,7955,1926,3328,3969,7955,1935,
.dw 3328,4721,7956,1999,3328,3536,9459,1926,
.dw 3329,3537,9459,1935,3329,3329,9459,1927,
.dw 3136,3968,9459,1798,3136,3969,9459,1935,
.dw 3136,4721,9460,1935,3136,3328,6291,1926,
.dw 3136,3329,6296,1871,3137,3137,6292,1927,
.dw 3136,3968,7955,1926,3136,3969,7955,1935,
.dw 3137,4721,7956,1999,3969,3328,9459,1926,
.dw 3970,3329,9459,1999,4209,3137,9459,1927,
.dw 4209,3968,9459,1990,4209,3969,9460,1935,
.dw 4209,4993,6291,1935,4209,3328,6295,1926,
.dw 4209,3329,6296,1871,4209,3137,6292,1927,
.dw 4209,4208,8419,1926,4209,4209,8419,1935,
.dw 4209,4993,8420,1999,4209,3328,6290,1926,
.dw 4209,3329,6290,1935,4209,3137,6290,1927,
.dw 4209,4208,6290,1926,4209,4209,6290,1935,
.dw 4209,4992,6290,-30833,4209,4992,6290,1935,
.dw 4209,4992,6290,1935,4209,4992,6290,1935,
.dw 4209,4992,6290,1935,4209,4992,6290,1935,
.dw 4209,4992,6290,1871,4209,4992,6290,1871,
.dw 4209,4992,6290,1807,4209,4992,6290,1935,
.dw 4209,4992,6290,1871,4209,4992,6290,1935,
.dw 4209,4992,6290,1935,4209,4992,6290,1935,
; Pattern 30:
.dw 4725,4720,9459,1862,4730,4720,9459,1999,
.dw 4725,4720,9459,1929,4730,4720,9459,1999,
.dw 4725,4723,9463,1804,4730,4723,9463,1935,
.dw 4735,4729,9467,1935,4735,4729,9467,1807,
.dw 4735,4729,9467,1935,4735,4729,9467,1935,
.dw 4735,4729,9467,1871,4735,4729,9467,1935,
.dw 4735,4729,9467,1999,4735,4735,9467,1935,
.dw 4735,4735,9471,1871,4735,4735,9471,1999,
.dw 4735,4735,9471,1871,4735,4735,9471,1999,
.dw 4735,4735,9471,-30769,4735,4735,9471,1999,
.dw 4735,4735,9471,1807,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1871,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1935,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1807,4735,4735,9471,1999,
.dw 4735,4735,9471,1807,4735,4735,9471,1999,
.dw 4735,4735,9471,1807,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1935,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1807,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,
.dw 4735,4735,9471,1935,4735,4735,9471,1935,
.dw 4735,4735,9471,1871,4735,4735,9471,1999,
.dw 4735,4735,9471,1935,4735,4735,9471,1999,
.dw 4735,4735,9471,1999,4735,4735,9471,1999,

.org $10000
.end
